@@ -47,12 +47,11 @@ def repr_consumer(message):
     print(repr(message))
 
 
+@interface.provider(m4us.ICoroutineFactory)
 class Counter(m4us.Component):
 
     """Count messages and pass them through."""
 
-    interface.classProvides(m4us.ICoroutineFactory)
-
     def _main(self):
         """Main loop for this component."""
         self.count = 0
