@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,14 +30,14 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
 
 #---  Project imports
 ## pylint: disable=W0611
-from m4us.core import init
+from m4us.core import init  ## NOQA
 ## pylint: enable=W0611
 
 
