@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -32,8 +32,10 @@ of in the package root (:mod:`m4us`), projects working under tight memory
 constraints can reduce the memory footprint of this project by instead directly
 importing only those modules they need.
 
-.. seealso:: :doc:`/api/index` and the various module documentation for details
-    on the available objects in imported into this module.
+.. seealso::
+
+  :doc:`/api/index` and the various module documentation for details on the
+  available objects in imported into this module.
 
 """
 
@@ -46,7 +48,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
@@ -55,20 +57,20 @@ from future_builtins import ascii, filter, hex, map, oct, zip
 from m4us.core import utils
 
 ## pylint: disable=W0401
-from m4us.core.api import *
+from m4us.core.api import *  ## NOQA
 ## pylint: enable=W0401
 ## pylint: disable=W0611
-from m4us.interfaces import (
+from m4us.interfaces import (  # NOQA
   IThreadedCoroutine,
   IBackplaneFactory,
   IBackplane,
   IRegisterPublisher,
   IUnregisterPublisher,
 )
-from m4us.concurrency import (
+from m4us.concurrency import (  # NOQA
   ThreadedCoroutine,
 )
-from m4us.backplanes import (
+from m4us.backplanes import (  # NOQA
   backplane,
   publish_to,
   NotRegisteredError,
