@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,13 +30,13 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core import api as core
@@ -64,11 +64,13 @@ def backplane():
     To subscribe to a `backplane`, just `link` to the `backplane`'s ``outbox``
     and ``signal`` `outboxes` like any other `publisher` `coroutine`.
 
-    :Implements: :class:`~m4us.interfaces.IBackplane`
-    :Provides: :class:`~m4us.interfaces.IBackplaneFactory`
+    :implements: :class:`m4us.interfaces.IBackplane`
+    :provides: :class:`m4us.interfaces.IBackplaneFactory`
 
-    .. seealso:: The :class:`~m4us.interfaces.IBackplane` interface for more
-        details on `backplanes`.
+    .. seealso::
+
+      The :class:`~m4us.interfaces.IBackplane` interface for more details on
+      `backplanes`.
 
     """
     publishers = set()
@@ -113,14 +115,16 @@ def publish_to(backplane_):
     `component`, the given :func:`backplane` object and a
     :func:`~m4us.core.coroutines.null_sink` `coroutine`.
 
-    :param backplane: The `backplane` object to which to publish `messages`.
-    :type backplane: :class:`~m4us.interfaces.IBackplane`
+    :param m4us.interfaces.IBackplane backplane: The `backplane` object to
+      which to publish `messages`.
 
     :returns: A container `component` that will publish all sent `messages` to
       the given `backplane`.
-    :rtype: :class:`~m4us.core.containers.Pipeline`
+    :rtype: :class:`m4us.core.containers.Pipeline`
 
-    .. note:: Since this function returns an
+    .. note::
+
+        Since this function returns an
         :class:`~m4us.core.interfaces.IContainer` `component`, remember to
         register it's `coroutines` and `links` with the `scheduler` and `post
         office`, or include it in another container.
@@ -139,8 +143,10 @@ class AlreadyRegisteredError(core.M4USException):
 
     The default message requires a ``publisher`` attribute or keyword argument.
 
-    .. seealso:: The :class:`~m4us.interfaces.IBackplane` `interface` for
-        details about this exeption's usage.
+    .. seealso::
+
+      The :class:`~m4us.interfaces.IBackplane` `interface` for details about
+      this exeption's usage.
 
     """
 
@@ -153,8 +159,10 @@ class NotRegisteredError(core.M4USException):
 
     The default message requires a ``publisher`` attribute or keyword argument.
 
-    .. seealso:: The :class:`~m4us.interfaces.IBackplane` `interface` for
-        details about this exeption's usage.
+    .. seealso::
+
+      The :class:`~m4us.interfaces.IBackplane` `interface` for details about
+      this exeption's usage.
 
     """
 
@@ -163,33 +171,31 @@ class NotRegisteredError(core.M4USException):
 
 #---  Messages
 
+@interface.implementer(interfaces.IRegisterPublisher)
+@interface.provider(core.IMessageFactory)
 class RegisterPublisher(core.Message):
 
     """`Message` for registering `publishers` with `backplanes`.
 
     :param publisher: The publishing object, specified as a keyword argument.
-    :type publisher: :class:`object`
 
-    :Implements: :class:`~m4us.interfaces.IRegisterPublisher`
-    :Provides: :class:`~m4us.core.interfaces.IMessageFactory`
+    :implements: :class:`m4us.interfaces.IRegisterPublisher`
+    :provides: :class:`m4us.core.interfaces.IMessageFactory`
 
-    .. seealso:: The :class:`Publisher` `component` and the
-        :class:`~m4us.interfaces.IBackplane` `interface` for details about how
-        this `message` is used.
+    .. seealso::
+
+      The :class:`Publisher` `component` and the
+      :class:`~m4us.interfaces.IBackplane` `interface` for details about how
+      this `message` is used.
 
     .. attribute:: publisher
 
         The `publisher` object to register.
 
-        :type: *any*
-
     """
 
     ## pylint: disable=R0903
 
-    interface.implements(interfaces.IRegisterPublisher)
-    interface.classProvides(core.IMessageFactory)
-
     def __init__(self, **kwargs):
         """See class docstring for this method's documentation."""
         # Note: The publisher argument should always be spcified as a keyword
@@ -198,36 +204,38 @@ class RegisterPublisher(core.Message):
         core.Message.__init__(self, **kwargs)
 
 
+## pylint: disable=R0903
+@interface.implementer_only(interfaces.IUnregisterPublisher)
+@interface.provider(core.IMessageFactory)
 class UnregisterPublisher(RegisterPublisher):
 
     """`Message` for unregistering `publishers` with `backplanes`.
 
     :param publisher: The publishing object, specified as a keyword argument.
-    :type publisher: :class:`object`
 
-    :Implements: :class:`~m4us.interfaces.IUnregisterPublisher`
-    :Provides: :class:`~m4us.core.interfaces.IMessageFactory`
+    :implements: :class:`m4us.interfaces.IUnregisterPublisher`
+    :provides: :class:`m4us.core.interfaces.IMessageFactory`
 
-    .. seealso:: The :class:`Publisher` `component` and the
-        :class:`~m4us.interfaces.IBackplane` `interface` for details about
-        how this `message` is used.
+    .. seealso::
+
+      The :class:`Publisher` `component` and the
+      :class:`~m4us.interfaces.IBackplane` `interface` for details about how
+      this `message` is used.
 
     .. attribute:: publisher
 
         The `publisher` object to unregister.
 
-        :type: *any*
-
     """
-
-    ## pylint: disable=R0903
-
-    interface.implementsOnly(interfaces.IUnregisterPublisher)
-    interface.classProvides(core.IMessageFactory)
+## pylint: enable=R0903
 
 
 #---  Components
 
+# This is needed so that all shutdown messages are emitted after the IShutdown
+# is sent in.
+@interface.implementer(core.INotLazy)
+@interface.provider(core.ICoroutineFactory)
 class Publisher(core.Component):
 
     """`Component` that registers with a `backplane` before sending `messages`.
@@ -247,32 +255,33 @@ class Publisher(core.Component):
     forwarded on, an :class:`~m4us.interfaces.IUnregisterPublisher` `message`
     is emitted first.
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine` and
-      :class:`~m4us.core.interfaces.INotLazy`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine` and
+      :class:`m4us.core.interfaces.INotLazy`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
-    .. seealso:: The :func:`publish_to` function for the normal way to publish
-        to a `backplane`.
+    .. seealso::
 
-    .. seealso:: The :class:`RegisterPublisher` and
-        :class:`UnregisterPublisher` classes as examples of concrete classes
-        that `publishers` can use for registration and unregistration.
+      The :func:`publish_to` function for the normal way to publish to a
+      `backplane`.
+
+    .. seealso::
+
+      The :class:`RegisterPublisher` and :class:`UnregisterPublisher` classes
+      as examples of concrete classes that `publishers` can use for
+      registration and unregistration.
 
     """
 
     ## pylint: disable=R0903
 
-    # This is needed so that all shutdown messages are emitted after the
-    # IShutdown is sent in.
-    interface.implements(core.INotLazy)
-    interface.classProvides(core.ICoroutineFactory)
-
     def _main(self):
         """Publish `messages` to a `backplane`.
 
-        .. seealso:: This class' docstring and the
-            :meth:`~m4us.core.interfaces.IComponent._main` method for details
-            about this method.
+        .. seealso::
+
+          This class' docstring and the
+          :meth:`~m4us.core.interfaces.IComponent._main` method for details
+          about this method.
 
         """
         current_inbox, current_message = (yield)
