@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,16 +30,16 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 import threading
 import Queue
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core import api as core
@@ -61,12 +61,12 @@ class _CoroutineThread(threading.Thread):
     This class' :meth:`run` method is designed to run a `coroutine`, delivering
     `messages` between the `coroutine` and the `message` queues.
 
-    :param coroutine: The `coroutine` to run in it's own thread.
-    :type coroutine: :class:`~m4us.core.interfaces.ICoroutine`
-    :param in_queue: The input queue of `messages` to send to the `coroutine`.
-    :type in_queue: :class:`~Queue.Queue`
-    :param out_queue: The output queue of `message` sent from the `coroutine`.
-    :type out_queue: :class:`~Queue.Queue`
+    :param m4us.core.interfaces.ICoroutine coroutine: The `coroutine` to run in
+      it's own thread.
+    :param Queue.Queue in_queue: The input queue of `messages` to send to the
+      `coroutine`.
+    :param Queue.Queue out_queue: The output queue of `message` sent from the
+      `coroutine`.
 
     """
 
@@ -97,13 +97,17 @@ class _CoroutineThread(threading.Thread):
         queue in the ``_thread_exception`` `outbox` and the thread will shut
         down.
 
-        .. note:: The thread only runs if there are `messages` in the input
-            queue, regardless of whether or not the `coroutine` is `lazy`.  It
-            is expected that ``('control', None)`` `messages` will be sent to
-            non-`lazy` `coroutines` in order to make them run every cycle.
+        .. note::
 
-        .. seealso:: The :class:`~m4us.core.interfaces.INotLazy` `interface`
-            for details on non-`lazy` `coroutines`.
+          The thread only runs if there are `messages` in the input queue,
+          regardless of whether or not the `coroutine` is `lazy`.  It is
+          expected that ``('control', None)`` `messages` will be sent to non-
+          `lazy` `coroutines` in order to make them run every cycle.
+
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.INotLazy` `interface` for details
+          on non-`lazy` `coroutines`.
 
         """
         while True:
@@ -127,6 +131,8 @@ class _CoroutineThread(threading.Thread):
                 self._in_queue.task_done()
 
 
+@interface.implementer(interfaces.IThreadedCoroutine, core.INotLazy)
+@interface.provider(core.ICoroutineFactory)
 class ThreadedCoroutine(object):
 
     """Wrapper that runs a `coroutine` in a separate thread.
@@ -140,42 +146,42 @@ class ThreadedCoroutine(object):
     exception is when either of the queue sizes are set and the queue is full.
     In that case, a method will hang until room becomes available in the queue.
 
-    :param coroutine: The `coroutine` to run in it's own thread.
-    :type coroutine: :class:`~m4us.core.interfaces.ICoroutine`
-    :param max_in_size: The maximum input queue size.  ``0`` means unlimited.
-    :type max_in_size: :class:`int`
-    :param max_out_size: The maximum output queue size.  ``0`` means unlimited.
-    :type max_out_size: :class:`int`
-    :param start: Whether or not to automatically start the thread.  If
+    :param m4us.core.interfaces.ICoroutine coroutine: The `coroutine` to run in
+      it's own thread.
+    :param int max_in_size: The maximum input queue size.  ``0`` means
+      unlimited.
+    :param int max_out_size: The maximum output queue size.  ``0`` means
+      unlimited.
+    :param bool start: Whether or not to automatically start the thread.  If
       disabled, the :meth:`start` method must be called explicitly.
-    :type start: :class:`bool`
 
-    :Implements: :class:`~m4us.interfaces.IThreadedCoroutine` and
-      :class:`~m4us.core.interfaces.INotLazy`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.interfaces.IThreadedCoroutine` and
+      :class:`m4us.core.interfaces.INotLazy`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
     Example usage:
 
     >>> scheduler.register(ThreadedCoroutine(my_coroutine()))
 
-    .. seealso:: The Python_ :class:`~Queue.Queue` class for more information
-        on limiting queue sizes.
+    .. seealso::
+
+      The Python_ :class:`Queue.Queue` class for more information on limiting
+      queue sizes.
 
     .. _Kamaelia: http://kamaelia.org
     .. _Python: http://python.org
 
     """
 
-    interface.implements(interfaces.IThreadedCoroutine, core.INotLazy)
-    interface.classProvides(core.ICoroutineFactory)
-
     ## pylint: disable=W0105
     _closed = False
     """Indicates whether or not instances of this class have been closed.
 
-    :type: :class:`bool`
+    :type: :obj:`bool`
 
-    .. seealso:: The :meth:`close` method for details.
+    .. seealso::
+
+      The :meth:`close` method for details.
 
     """
     ## pylint: enable=W0105
@@ -201,7 +207,7 @@ class ThreadedCoroutine(object):
         exception is raised.
 
         :returns: A queued up output `message`, if one exists.
-        :rtype: 2-:class:`tuple` or :obj:`None`
+        :rtype: :obj:`tuple` or :obj:`None`
 
         :raises: Any queued up exceptions coming from the `coroutine`.
 
@@ -220,11 +226,15 @@ class ThreadedCoroutine(object):
     def start(self):
         """Start the `coroutine` thread if it needs explicit starting.
 
-        .. seealso:: :class:`~m4us.interfaces.IThreadedCoroutine` for details
-            about this method.
+        .. seealso::
 
-        .. seealso:: This class's docstring for details about the implicit and
-            explicit starting of the `coroutine` thread.
+          :class:`~m4us.interfaces.IThreadedCoroutine` for details about this
+          method.
+
+        .. seealso::
+
+          This class's docstring for details about the implicit and explicit
+          starting of the `coroutine` thread.
 
         """
         self._thread.start()
@@ -232,16 +242,22 @@ class ThreadedCoroutine(object):
     def send(self, message):
         """Send and receive `messages` to and from the `coroutine`.
 
-        .. note:: ``('control', None)`` `inbox` `messages` will only be sent to
-            the `coroutine` if it is not `lazy` (i.e. it provides the
-            :class:`~m4us.core.interfaces.INotLazy` marker `interface`).
+        .. note::
 
-        .. note:: Any `message` returned will be the next one in the output
-            queue, and not necessarily the immediate response to the given
-            `message` when sent.
+          ``('control', None)`` `inbox` `messages` will only be sent to the
+          `coroutine` if it is not `lazy` (i.e. it provides the
+          :class:`~m4us.core.interfaces.INotLazy` marker `interface`).
 
-        .. seealso:: :class:`~m4us.core.interfaces.ICoroutine` for details
-            about this method.
+        .. note::
+
+          Any `message` returned will be the next one in the output queue, and
+          not necessarily the immediate response to the given `message` when
+          sent.
+
+        .. seealso::
+
+          :class:`~m4us.core.interfaces.ICoroutine` for details about this
+          method.
 
         """
         if self._closed:
@@ -254,17 +270,23 @@ class ThreadedCoroutine(object):
     def throw(self, exception):
         """Throw an exception inside the threaded `coroutine`.
 
-        .. note:: The thrown exception is queued up, in order, with other sent
-            `messages` and so the threaded `coroutine` may not react to it
-            immediately.
+        .. note::
 
-        .. note:: Like the :meth:`send` method, any `message` returned will be
-            the next one in the output queue, and not necessarily the
-            immediate response given exception.  This includes the raising of
-            any handled exceptions.
+          The thrown exception is queued up, in order, with other sent
+          `messages` and so the threaded `coroutine` may not react to it
+          immediately.
 
-        .. seealso:: :class:`~m4us.core.interfaces.ICoroutine` for details
-            about this method.
+        .. note::
+
+          Like the :meth:`send` method, any `message` returned will be the next
+          one in the output queue, and not necessarily the immediate response
+          given exception.  This includes the raising of any handled
+          exceptions.
+
+        .. seealso::
+
+          :class:`~m4us.core.interfaces.ICoroutine` for details about this
+          method.
 
         """
         if self._closed:
@@ -275,8 +297,10 @@ class ThreadedCoroutine(object):
     def close(self):
         """Close the `coroutine` and shutdown it's thread.
 
-        .. seealso:: :class:`~m4us.core.interfaces.ICoroutine` for details
-            about this method.
+        .. seealso::
+
+          :class:`~m4us.core.interfaces.ICoroutine` for details about this
+          method.
 
         """
         if self._closed:
