@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -26,8 +26,10 @@ of in the package root (:mod:`m4us`), projects working under tight memory
 constraints can reduce the memory footprint of this project by instead directly
 importing only those modules they need.
 
-.. seealso:: :doc:`/api/core/index` and the various core module documentation
-    for details on the available objects in imported into this module.
+.. seealso::
+
+  :doc:`/api/core/index` and the various core module documentation for details
+  on the available objects in imported into this module.
 
 """
 
@@ -40,7 +42,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
@@ -49,7 +51,7 @@ from future_builtins import ascii, filter, hex, map, oct, zip
 from m4us.core import utils
 
 ## pylint: disable=W0611
-from m4us.core.interfaces import (
+from m4us.core.interfaces import (  # NOQA
   #---  Messages interfaces
   IMessage,
   IMessageFactory,
@@ -69,7 +71,7 @@ from m4us.core.interfaces import (
   IScheduler,
   ISchedulerFactory,
 )
-from m4us.core.exceptions import (
+from m4us.core.exceptions import (  # NOQA
   M4USException,
   #---  Postoffices exceptions
   LinkExistsError,
@@ -82,12 +84,12 @@ from m4us.core.exceptions import (
   #---  Containers exceptions
   InvalidLinkError,
 )
-from m4us.core.messages import (
+from m4us.core.messages import (  # NOQA
   Message,
   Shutdown,
   ProducerFinished,
 )
-from m4us.core.coroutines import (
+from m4us.core.coroutines import (  # NOQA
   init,
   coroutine,
   sample_coroutine,
@@ -99,21 +101,21 @@ from m4us.core.coroutines import (
   sink_from_callable,
   sink,
 )
-from m4us.core.components import (
+from m4us.core.components import (  # NOQA
   Component,
   SampleComponent,
 )
-from m4us.core.containers import (
+from m4us.core.containers import (  # NOQA
   Graphline,
   Pipeline,
 )
-from m4us.core.postoffices import (
+from m4us.core.postoffices import (  # NOQA
   PostOffice,
 )
-from m4us.core.schedulers import (
+from m4us.core.schedulers import (  # NOQA
   Scheduler,
 )
-from m4us.core.utils import (
+from m4us.core.utils import (  # NOQA
   easy_link,
   is_shutdown,
 )
