@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -36,16 +36,17 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
+## pylint: enable=F0401
 # This is imported directly for the sample coroutine
 ## pylint: disable=F0401
-from zope.interface import classProvides
-## pylint: enable=E0611, F0401
+from zope.interface import provider
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core import interfaces
@@ -62,6 +63,8 @@ from m4us.core.interfaces import ICoroutineFactory
 
 #---Classes--------------------------------------------------------------------
 
+@interface.implementer(interfaces.ICoroutine)
+@interface.provider(interfaces.ICoroutineFactory)
 class Component(object):
 
     """Base class for `components`.
@@ -73,12 +76,12 @@ class Component(object):
     `Components` have an internal `coroutine` defined in the :meth:`_main`
     method, which sub-classes should implement.
 
-    :param kwargs: Any keyword arguments given at instantiation are
-      automatically set as instance attributes for convenience.
-    :type kwargs: :class:`dict`
+    :param collections.Mapping kwargs: Any keyword arguments given at
+      instantiation are automatically set as instance attributes for
+      convenience.
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
     .. _Kamaelia: http://www.kamaelia.org/
 
@@ -86,9 +89,6 @@ class Component(object):
 
     """
 
-    interface.implements(interfaces.ICoroutine)
-    interface.classProvides(interfaces.ICoroutineFactory)
-
     def __init__(self, **kwargs):
         """See class docstring for this method's documentation."""
         self.__dict__.update(kwargs)
@@ -114,8 +114,10 @@ class Component(object):
         This method just passes the `message` on to the internal `coroutine`
         defined in :meth:`_main`, returning any resulting `message`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.ICoroutine` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.ICoroutine` `interface` for details
+          about this method.
 
         """
         return self._coroutine.send(message)
@@ -127,8 +129,9 @@ class Component(object):
         defined in :meth:`_main`, returning any resulting `message` or raising
         the uncaught exception.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.ICoroutine` `interface`
-            for details about this method.
+        .. seealso::
+          The :class:`~m4us.core.interfaces.ICoroutine` `interface` for details
+          about this method.
 
         """
         return self._coroutine.throw(exception)
@@ -139,20 +142,21 @@ class Component(object):
         This method just calls :meth:`!close` on the `component`'s internal
         `coroutine` defined in :meth:`_main`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.ICoroutine` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.ICoroutine` `interface` for details
+          about this method.
 
         """
         self._coroutine.close()
 
 
 # [[start SampleComponent]]
+@provider(ICoroutineFactory)
 class SampleComponent(Component):
 
     """Component that passes all messages through."""
 
-    classProvides(ICoroutineFactory)
-
     def _main(self):
         """Pass all messages through."""
         inbox, message = (yield)
@@ -188,11 +192,13 @@ class SampleComponent(Component):
         :start-after: # [[start SampleComponent]]
         :end-before: # [[end SampleComponent]]
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
-    .. seealso:: The :func:`~m4us.core.coroutines.sample_coroutine` `coroutine`
-        for details on why the :meth:`_main` method is written the way it is.
+    .. seealso::
+
+      The :func:`~m4us.core.coroutines.sample_coroutine` `coroutine` for
+      details on why the :meth:`!_main` method is written the way it is.
 
     """
 
