@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -39,13 +39,13 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core import components, utils, exceptions, interfaces
@@ -59,6 +59,8 @@ from m4us.core import components, utils, exceptions, interfaces
 
 #---Classes--------------------------------------------------------------------
 
+@interface.implementer(interfaces.IContainer)
+@interface.provider(interfaces.IContainerFactory, interfaces.ICoroutineFactory)
 class Graphline(components.Component):
 
     """Container `component` of `coroutines` with fully configurable `links`.
@@ -120,33 +122,30 @@ class Graphline(components.Component):
         coroutine2 -> graphline [ label = "4" ]
         coroutine3 -> graphline [ label = "4" ]
 
-    :param links: The `links` and `coroutines` to contain.  Each `link` should
-      be in the form of :samp:`({source}, {outbox}, {sink}, {inbox})`.
-    :type links: :class:`tuple` of 4-:class:`tuple`\s
-    :param kwargs: Any keyword arguments will be set as attributes on the
-      instance.
-    :type kwargs: :class:`dict`
+    :param collections.Sequence links: The `links` and `coroutines` to
+      contain.  Each `link` should be in the form of :samp:`({source},
+      {outbox}, {sink}, {inbox})`.
+    :param collections.Mapping kwargs: Any keyword arguments will be set as
+      attributes on the instance.
 
     :raises m4us.core.exceptions.InvalidLinkError: If an invalid `link`
       involving the :class:`Graphline`'s `mailboxes` is attempted.
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine` and
-      :class:`~m4us.core.interfaces.IContainer`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory` and
-      :class:`~m4us.core.interfaces.IContainerFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine` and
+      :class:`m4us.core.interfaces.IContainer`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory` and
+      :class:`m4us.core.interfaces.IContainerFactory`
 
-    .. seealso:: The :class:`~m4us.core.interfaces.ICoroutine` and
-        :class:`~m4us.core.interfaces.IContainer` `interfaces` for details on
-        the methods and attributes provided by instances of this class.
+    .. seealso::
+
+      The :class:`~m4us.core.interfaces.ICoroutine` and
+      :class:`~m4us.core.interfaces.IContainer` `interfaces` for details on the
+      methods and attributes provided by instances of this class.
 
     .. _Kamaelia: http://kamaelia.org
 
     """
 
-    interface.implements(interfaces.IContainer)
-    interface.classProvides(interfaces.IContainerFactory,
-      interfaces.ICoroutineFactory)
-
     def __init__(self, *links, **kwargs):
         """See class docstring for this method's documentation."""
         components.Component.__init__(self, **kwargs)
@@ -158,15 +157,12 @@ class Graphline(components.Component):
         """If the `coroutine` is a `container`, add include it's children.
 
         If the `coroutine` is an
-        :class:`m4us.core.interfaces.IContainer`, then it's `coroutines` are
+        :class:`~m4us.core.interfaces.IContainer`, then it's `coroutines` are
         added to the :class:`list` and :class:`set` of `coroutines.
 
-        :param coroutine: The `coroutine` to check.
-        :type coroutine: :class:`ICoroutine`
-        :param coroutines: Pre-existing list of `coroutines` to extend.
-        :type coroutines: :class:`list`
-        :param coroutines_set: Pre-existing set of `coroutines` to extend.
-        :type coroutines_set: :class:`set`
+        :param ICoroutine coroutine: The `coroutine` to check.
+        :param list coroutines: Pre-existing list of `coroutines` to extend.
+        :param set coroutines_set: Pre-existing set of `coroutines` to extend.
 
         """
         container = interfaces.IContainer(coroutine, None)
@@ -184,11 +180,11 @@ class Graphline(components.Component):
         including the :class:`Graphline` instance.
 
         If any `coroutine` is also an
-        :class:`m4us.core.interfaces.IContainer`, then it's `coroutines` are
+        :class:`~m4us.core.interfaces.IContainer`, then it's `coroutines` are
         included automatically.
 
-        :param links: The `post office` `links` given at instantiation.
-        :type links: iterable of 4-:class:`tuple`'s
+        :param collections.Iterable links: The `post office` `links` given at
+          instantiation.
 
         """
         coroutines, coroutines_set = [self], set()
@@ -206,18 +202,20 @@ class Graphline(components.Component):
         Any `links` that use ``'self'`` as the `source` or `sink` are converted
         to `links` to or from the :class:`Graphline` instance.
 
-        :param links: The `post office` `links` given at instantiation.
-        :type links: iterable of 4-:class:`tuple`'s
+        :param collections.Iterable links: The `post office` `links` given at
+          instantiation.
 
         If any `coroutine` is also an
-        :class:`m4us.core.interfaces.IContainer`, then it's `links` are
+        :class:`~m4us.core.interfaces.IContainer`, then it's `links` are
         included automatically.
 
         :raises m4us.core.exceptions.InvalidLinkError: If an invalid `link`
           involving the :class:`Graphline`'s `mailboxes` is attempted.
 
-        .. seealso:: The class's docstring for more details on how ``'self'``
-            `links` are handled.
+        .. seealso::
+
+          The class's docstring for more details on how ``'self'`` `links` are
+          handled.
 
         """
         prepared_links = set()
@@ -262,10 +260,12 @@ class Graphline(components.Component):
         out from this class.
 
         :returns: The container's `coroutine`.
-        :rtype: :class:`~m4us.core.interfaces.ICoroutine`
+        :rtype: :class:`m4us.core.interfaces.ICoroutine`
 
-        .. seealso:: The :meth:`m4us.core.interfaces.IComponent._main` method
-            for more details on this method.
+        .. seealso::
+
+          The :meth:`~m4us.core.interfaces.IComponent._main` method for more
+          details on this method.
 
         """
         mailbox_map = {
@@ -283,6 +283,7 @@ class Graphline(components.Component):
     ## pylint: enable=R0201
 
 
+@interface.provider(interfaces.IContainerFactory, interfaces.ICoroutineFactory)
 class Pipeline(Graphline):
 
     """Container `component` of `coroutines` that `links` them in a pipeline.
@@ -325,31 +326,31 @@ class Pipeline(Graphline):
         coroutine2 -> coroutine3 [ label = "4" ]
         coroutine3 -> pipeline [ label = "5" ]
 
-    :param first_coroutine: The first `coroutine` in the pipeline.  It will
-      receive incomming `messages` to the pipeline.
-    :type first_coroutine: :class:`~m4us.core.interfaces.ICoroutine`
-    :param other_coroutines: Any other `coroutines` in the pipeline, in order.
-      `Messages` emmitted by the last one will be emitted by the pipeline.
-    :type other_coroutines: :class:`tuple` of
-      :class:`~m4us.core.interfaces.ICoroutine`\s
-    :param kwargs: Like other `components`, any given keyword arguments will be
-      set as instance attributes.
-    :type kwargs: :class:`dict`
+    :param m4us.core.interfaces.ICoroutine first_coroutine: The first
+      `coroutine` in the pipeline.  It will receive incomming `messages` to the
+      pipeline.
+    :param m4us.core.interfaces.ICoroutine second_coroutine: The second
+      `coroutine` in the pipeline.  It will receive incomming `messages` to the
+      pipeline.
+    :param collections.Sequence other_coroutines: Any other `coroutines` in the
+      pipeline, in order. `Messages` emmitted by the last one will be emitted
+      by the pipeline.
+    :param collections.Mapping kwargs: Like other `components`, any given
+      keyword arguments will be set as instance attributes.
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine` and
-      :class:`~m4us.core.interfaces.IContainer`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory` and
-      :class:`~m4us.core.interfaces.IContainerFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine` and
+      :class:`m4us.core.interfaces.IContainer`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory` and
+      :class:`m4us.core.interfaces.IContainerFactory`
 
-    .. seealso:: The :class:`~m4us.core.interfaces.ICoroutine` and
-        :class:`~m4us.core.interfaces.IContainer` `interfaces` for details on
-        the methods and attributes provided by instances of this class.
+    .. seealso::
+
+      The :class:`~m4us.core.interfaces.ICoroutine` and
+      :class:`~m4us.core.interfaces.IContainer` `interfaces` for details on the
+      methods and attributes provided by instances of this class.
 
     """
 
-    interface.classProvides(interfaces.IContainerFactory,
-      interfaces.ICoroutineFactory)
-
     def __init__(self, first_coroutine, second_coroutine, *other_coroutines,
       **kwargs):
         """See class docstring for this method's documentation."""
@@ -374,16 +375,17 @@ class Pipeline(Graphline):
         appropriately so that `messages` to and from the class itself are
         delivered as expected.
 
-        :param coroutines: The `coroutines` to link together.
-        :type coroutines: :class:`tuple` of
-          :class:`~m4us.core.interfaces.ICoroutine`\s
+        :param collections.Sequence coroutines: The `coroutines` to link
+          together.
 
         :returns: The collection of `links` to pass to the parent
           :class:`Graphline` class.
-        :rtype: :class:`set` of link :class:`tuples`
+        :rtype: :obj:`set`
 
-        .. seealso:: The :class:`Graphline` class for details on the `link`
-            format and the use of ``'self'`` in them.
+        .. seealso::
+
+          The :class:`Graphline` class for details on the `link` format and the
+          use of ``'self'`` in them.
 
         """
         links = utils.easy_link(*coroutines)
@@ -402,9 +404,8 @@ class Pipeline(Graphline):
         This method has been overridden to handle sub-containers while still
         preserving the coroutine order as best as it can.
 
-        :param links: The `post office` `links` given at instantiation.  *(Not
-          used)*.
-        :type links: iterable of 4-:class:`tuple`'s
+        :param collections.Iterable links: The `post office` `links` given at
+          instantiation.  *(Not used)*.
 
         """
         coroutines, coroutines_set = [self], set()
