@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -34,15 +34,15 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 import types
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 import decorator
 
 #---  Project imports
@@ -73,7 +73,7 @@ def _interface_adapter_hook(interface_, coroutine_, registry=None):
     declare provided interfaces directly.  They do not need this adapter.
 
     Python_ `coroutines`, on the other hand, are really instances of
-    :class:`~types.GeneratorType`.  They cannot be made to directly declare
+    :data:`types.GeneratorType`.  They cannot be made to directly declare
     proivided interfaces because one cannot add additional attributes to the
     `generator` object.  That is where this `adapter` comes in.
 
@@ -88,14 +88,14 @@ def _interface_adapter_hook(interface_, coroutine_, registry=None):
     the `coroutine` itself, adaptation to the given `interface` happens
     transparently.
 
-    :param interface_: The `interface` that must be provided.
-    :type interface_: :class:`~zope.interface.Interface`
-    :param coroutine_: The `coroutine` to verify.
-    :type coroutine_: :class:`~m4us.core.interfaces.ICoroutine`
+    :param zope.interface.Interface interface_: The `interface` that must be
+      provided.
+    :param m4us.core.interfaces.ICoroutine coroutine_: The `coroutine` to
+      verify.
 
     :returns: The given `coroutine` if it provides the `interface` or
       :obj:`None` otherwise.
-    :rtype: :class:`~m4us.core.interfaces.ICoroutine` or :obj:`None`
+    :rtype: :class:`m4us.core.interfaces.ICoroutine` or :obj:`None`
 
     """
     if registry is None:
@@ -128,21 +128,19 @@ def _curried_coroutine_factory(function, coroutine_factory_path):
     accepts all additional arguments except the first one in case the function
     requires additional arguments.
 
-    :param function: The function to wrap.  It must accept at least one
-      argument.
-    :type function: :obj:`~types.FunctionType`
-    :param coroutine_factory_path: The import path to the coroutine factory
+    :param types.FunctionType function: The function to wrap.  It must accept
+      at least one argument.
+    :param str coroutine_factory_path: The import path to the coroutine factory
       function to call.
-    :type coroutine_factory_path: :obj:`str`
 
     :returns: A coroutine factory with the function curried into it.
-    :rtype: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :rtype: :class:`m4us.core.interfaces.ICoroutineFactory`
 
-    :raises TypeError: If the given function is not a function.
-    :raises ValueError: If the given function does not accept at least one
-      positional argument.
+    :raises exceptions.TypeError: If the given function is not a function.
+    :raises exceptions.ValueError: If the given function does not accept at
+      least one positional argument.
 
-    :seealso: :func:`m4us.core.utils._function_wrapper_from_template` for
+    :seealso: :func:`~m4us.core.utils._function_wrapper_from_template` for
       additional details.
 
     """
@@ -201,17 +199,24 @@ def coroutine(lazy=True):
     `interfaces` implemented by the function as being provided by the
     `coroutine` that the function returns.
 
-    :param lazy: Specifies whether or not the `coroutine` is `lazy`.
-    :type lazy: :class:`bool`
+    :param bool lazy: Specifies whether or not the `coroutine` is `lazy`.
 
     :returns: A wrapper function that will activate and return the `coroutine`
       when called.
-    :rtype: :class:`~types.FunctionType`
+    :rtype: :data:`types.FunctionType`
 
-    .. warning:: When using this decorator with the
-      :func:`zope.interface.implementer` and/or :func:`zope.interface.provider`
-      decorators, make sure this decorator is the outer-most one.  Otherwise
-      interface declarations will get lost.
+    .. warning::
+
+      When using this decorator with the zope.interface.implementer_ and/or
+      zope.interface.provider_ decorators, make sure this decorator is the
+      outer-most one.  Otherwise interface declarations will get lost.
+
+    .. _zope.interface.implementer:
+      http://docs.zope.org/zope.interface/README.html
+      #declaring-implemented-interfaces
+    .. _zope.interface.provider:
+      http://docs.zope.org/zope.interface/README.html
+      #declaring-provided-interfaces
 
     """
     def _coroutine_factory(function, *args, **kwargs):
@@ -272,16 +277,18 @@ sample_coroutine.__doc__ = """Pass all `messages` through.
         :end-before: # [[end sample_coroutine]]
 
     :returns: A pass-through `coroutine`
-    :rtype: :class:`~types.GeneratorType`
+    :rtype: :data:`types.GeneratorType`
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
-    .. note:: `Producers` and `filters` need a minimum of 2 :keyword:`yield`
-        statements as the output of the first one is always thrown away.  The
-        output of the second one is the first `message` delivered.  On the
-        other hand, the first :keyword:`yield` will be the one that gets the
-        first incoming `message`.
+    .. note::
+
+      `Producers` and `filters` need a minimum of 2 :keyword:`yield` statements
+      as the output of the first one is always thrown away.  The output of the
+      second one is the first `message` delivered.  On the other hand, the
+      first :keyword:`yield` will be the one that gets the first incoming
+      `message`.
 
     """
 ## pylint: enable=W0622
@@ -301,10 +308,10 @@ def null_sink():
     quitting.
 
     :returns: A null sink `coroutine`
-    :rtype: :class:`~types.GeneratorType`
+    :rtype: :data:`types.GeneratorType`
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
     """
     while True:
@@ -337,22 +344,23 @@ def filter_from_callable(callable_, *args, **kwargs):
     Non-:obj:`None` `messages` will still be emitted on the ``outbox``
     `outbox`, however.
 
-    :param callable\_: The callable to which to pass messages.
-    :type callable\_: Any callable object
-    :param suppress_none: Indicate whether or not :obj:`None` should be emitted
-      on the ``outbox`` `outbox`.  (Default: :obj:`True`)
-    :type suppress_none: :obj:`bool`
-    :param \*args: Any additional positional arguments to pass to the callable.
-    :param \*\*kwargs: Any additional keyword arguments to pass to the
-      callable.
+    :param collections.Callable callable\_: The callable to which to pass
+      messages.
+    :param bool suppress_none: Indicate whether or not :obj:`None` should be
+      emitted on the ``outbox`` `outbox`.  (Default: :obj:`True`)
+    :param collections.Sequence args: Any additional positional arguments to
+      pass to the callable.
+    :param collections.Mapping kwargs: Any additional keyword arguments to pass
+      to the callable.
 
     :returns: A filter `coroutine`
-    :rtype: :class:`~types.GeneratorType`
+    :rtype: :data:`types.GeneratorType`
 
-    :raises TypeError: If the given callable is not actually a callable.
+    :raises exceptions.TypeError: If the given callable is not actually a
+      callable.
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
     """
     if not callable(callable_):
@@ -388,16 +396,15 @@ def filter_(function):
     The factory function is also registered as providing
     :class:`~m4us.core.interfaces.ICoroutineFactory`.
 
-    :param function: The function to turn into a `coroutine`.  It must accept
-      at least one argument.
-    :type function: :class:`~types.FunctionType`
+    :param types.FunctionType function: The function to turn into a
+      `coroutine`.  It must accept at least one argument.
 
     :returns: A filter coroutine factory function.
-    :rtype: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :rtype: :class:`m4us.core.interfaces.ICoroutineFactory`
 
-    :raises TypeError: If the given function is not a function.
-    :raises ValueError: If the given function does not accept at least one
-      positional argument.
+    :raises exceptions.TypeError: If the given function is not a function.
+    :raises exceptions.ValueError: If the given function does not accept at
+      least one positional argument.
 
     :seealso: :func:`filter_from_callable` for the specifics.
 
@@ -415,17 +422,17 @@ def producer_from_iterable(iterable):
     have been emitted, an :class:`~m4us.core.interfaces.IProducerFinished`
     messages is emitted.  Then the `producer` terminates.
 
-    :param iterable: The iterable object over which to iterate.
-    :type iterable: Any iterable
+    :param collections.Iterable iterable: The iterable object over which to
+      iterate.
 
     :returns: A non-lazy producer `coroutine`
-    :rtype: :class:`~types.GeneratorType`
+    :rtype: :data:`types.GeneratorType`
 
-    :raises TypeError: If the given object is not an iterable or it does not
-      produce a valid iterator.
+    :raises exceptions.TypeError: If the given object is not an iterable or it
+      does not produce a valid iterator.
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
     """
     iterator = iter(iterable)
@@ -451,19 +458,24 @@ def producer(generator_factory):
     The factory function is also registered as providing
     :class:`~m4us.core.interfaces.ICoroutineFactory`.
 
-    :param generator_factory: The generator function to turn into a `producer`.
-    :type function: :class:`~types.FunctionType`
+    :param types.FunctionType generator_factory: The generator function to turn
+      into a `producer`.
 
     :returns: A `producer` `coroutine` factory function.
-    :rtype: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :rtype: :class:`m4us.core.interfaces.ICoroutineFactory`
 
-    :raises TypeError: If the given generator factory is not a callable.
+    :raises exceptions.TypeError: If the given generator factory is not a
+      callable.
 
-    .. note:: Technically this decorator will work with any function that
-        returns an iterable.  A generator function is not strictly required,
-        though that is the expected typical use case.
+    .. note::
 
-    :seealso: :func:`producer_from_iterable` for the specifics.
+      Technically this decorator will work with any function that returns an
+      iterable.  A generator function is not strictly required, though that is
+      the expected typical use case.
+
+    :seealso:
+
+      :func:`producer_from_iterable` for the specifics.
 
     """
     def _producer_factory(generator_factory, *args, **kwargs):
@@ -496,19 +508,21 @@ def sink_from_callable(callable_, *args, **kwargs):
     Any ``control`` or non-``inbox`` `messages` sent in will be ignored and not
     passed to the callable.
 
-    :param callable\_: The callable to which to pass messages.
-    :type callable\_: Any callable object
-    :param \*args: Any additional positional arguments to pass to the callable.
-    :param \*\*kwargs: Any additional keyword arguments to pass to the
-      callable.
+    :param collections.Callable callable\_: The callable to which to pass
+      messages.
+    :param collections.Sequence args: Any additional positional arguments to
+      pass to the callable.
+    :param collections.Mapping kwargs: Any additional keyword arguments to pass
+      to the callable.
 
     :returns: A `sink` `coroutine`
-    :rtype: :class:`~types.GeneratorType`
+    :rtype: :data:`types.GeneratorType`
 
-    :raises TypeError: If the given callable is not actually a callable.
+    :raises exceptions.TypeError: If the given callable is not actually a
+      callable.
 
-    :Implements: :class:`~m4us.core.interfaces.ICoroutine`
-    :Provides: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :implements: :class:`m4us.core.interfaces.ICoroutine`
+    :provides: :class:`m4us.core.interfaces.ICoroutineFactory`
 
     """
     def _sink_from_callable(*args, **kwargs):
@@ -535,18 +549,17 @@ def sink(function):
     The factory function is also registered as providing
     :class:`~m4us.core.interfaces.ICoroutineFactory`.
 
-    :param function: The function to turn into a `sink` `coroutine`.  It must
-      accept at least one argument.
-    :type function: :class:`~types.FunctionType`
+    :param types.FunctionType function: The function to turn into a `sink`
+      `coroutine`.  It must accept at least one argument.
 
     :returns: A `sink` `coroutine` factory function.
-    :rtype: :class:`~m4us.core.interfaces.ICoroutineFactory`
+    :rtype: :class:`m4us.core.interfaces.ICoroutineFactory`
 
-    :raises TypeError: If the given function is not a function.
-    :raises ValueError: If the given function does not accept at least one
-      positional argument.
+    :raises exceptions.TypeError: If the given function is not a function.
+    :raises exceptions.ValueError: If the given function does not accept at
+      least one positional argument.
 
-    :seealso: :func:`sink_from_callable` for the specifics.
+    .. seealso:: :func:`sink_from_callable` for the specifics.
 
     """
     return _curried_coroutine_factory(function,
