@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -32,13 +32,13 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 
@@ -57,19 +57,21 @@ class IMessageFactory(interface.Interface):
 
     """`Interface` for `callables` that return :class:`IMessage` objects."""
 
-    def __call__(**kwargs):
+    def __call__(**kwargs):  # pragma: no branch
         """Return the desired `message`.
 
         The `callable` should only be called with keyword arguments.
 
-        :param kwargs: Keywords arguments to pass to the `factory` `callable`.
-        :type kwargs: :class:`dict`
+        :param collections.Mapping kwargs: Keywords arguments to pass to the
+          `factory` `callable`.
 
         :returns: The desired `message` object.
         :rtype: :class:`IMessage`
 
-        .. note:: All unrecognized keyword arguments should be set as
-            attributes on the :class:`IMessage` object.
+        .. note::
+
+          All unrecognized keyword arguments should be set as attributes on the
+          :class:`IMessage` object.
 
         """
 
@@ -101,13 +103,13 @@ class ICoroutineFactory(interface.Interface):
 
     """`Interface` for `callables` that return :class:`ICoroutine` objects."""
 
-    def __call__(*args, **kwargs):
+    def __call__(*args, **kwargs):  # pragma: no branch
         """Return the desired `coroutine`.
 
-        :param args: Any arguments to pass to the `factory` `callable`.
-        :type args: :class:`tuple`
-        :param kwargs: Keywords arguments to pass to the `factory` `callable`.
-        :type kwargs: :class:`dict`
+        :param collections.Sequence args: Any arguments to pass to the
+          `factory` `callable`.
+        :param collections.Mapping kwargs: Keywords arguments to pass to the
+          `factory` `callable`.
 
         :returns: The desired `coroutine`.
         :rtype: :class:`ICoroutine`
@@ -121,70 +123,75 @@ class ICoroutine(interface.Interface):
 
     Python_ `coroutines` are defined in :PEP:`342`.
 
-    .. note:: While Python_ `coroutines` are an extension of `generators`, and
-        as such define a ``next()`` method, this `interface` does not include
-        the ``next()`` method as it really only makes sense in the context of
-        actual `generators` rather than for `coroutines`.
+    .. note::
 
-    .. note:: By default, all Python_ `coroutines` (i.e.
-        :class:`~types.GeneratorType`) have been automatically configured to
-        provide :class:`ICoroutine`.  This makes working with Python_
-        `coroutines` more natural.
+      While Python_ `coroutines` are an extension of `generators`, and as such
+      define a ``next()`` method, this `interface` does not include the
+      ``next()`` method as it really only makes sense in the context of actual
+      `generators` rather than for `coroutines`.
+
+    .. note::
+
+      By default, all Python_ `coroutines` (i.e. :data:`types.GeneratorType`)
+      have been automatically configured to provide :class:`ICoroutine`.  This
+      makes working with Python_ `coroutines` more natural.
 
     .. _Python: http://python.org/
 
     """
 
-    def send(message):
+    def send(message):  # pragma: no branch
         """Send the `message` to the `coroutine`.
 
         :param message: The `message` object to send into the `coroutine`.  For
-          this project it will normally be a 2-:class:`tuple` of the `inbox`
+          this project it will normally be a 2-:obj:`tuple` of the `inbox`
           and the `message`.
-        :type message: :class:`object`
 
         :returns: Any `message` :keyword:`yield`\ed by the `coroutine`.  For
-          this project it will normally be a 2-:class:`tuple` of the `outbox`
+          this project it will normally be a 2-:obj:`tuple` of the `outbox`
           and the `message`.
-        :rtype: :class:`object`
 
         :raises exceptions.StopIteration: If the `coroutine` has terminated,
           either by :keyword:`return`\ing (as opposed to :keyword:`yield`\ing)
           or because the :meth:`close` method was called.
 
-        .. note:: The first call to this method must pass :obj:`None` as the
-            sole argument. This activates the `coroutine`.  The response from
-            the first call is undefined.
+        .. note::
+
+          The first call to this method must pass :obj:`None` as the sole
+          argument. This activates the `coroutine`.  The response from the
+          first call is undefined.
 
         """
 
-    def throw(exception):
+    def throw(exception):  # pragma: no branch
         """Send the exception to the `coroutine`.
 
         The `coroutine` is expected to raise the exception in it's context at
         the reception point.  It may then catch it and handle it or not.
 
-        :param exception: The exception to send to the `coroutine`.
-        :type exception: :class:`Exception`
+        :param exceptions.Exception exception: The exception to send to the
+          `coroutine`.
 
         :returns: If the exception is caught, then any `message`
           :keyword:`yield`\ed by the `coroutine`.
-        :rtype: :class:`object`
 
-        :raises: Any uncaught exception passed in via this method.
+        :raises exceptions.Exception: Any uncaught exception passed in via this
+          method.
 
         """
 
-    def close():
+    def close():  # pragma: no branch
         """Terminate the `coroutine`.
 
-        This method sends the :exc:`GeneratorExit` exception into the
-        `coroutine`, which is expected to perform any necessary clean up and
-        shutdown work and then terminate.
+        This method sends the :exc:`~exceptions.GeneratorExit` exception into
+        the `coroutine`, which is expected to perform any necessary clean up
+        and shutdown work and then terminate.
 
-        .. note:: After this method is called, all subsequent calls to
-            :meth:`send` **must** result in a :exc:`StopIteration` exception
-            being raised.
+        .. note::
+
+          After this method is called, all subsequent calls to :meth:`send`
+          **must** result in a :exc:`~exceptions.StopIteration` exception being
+          raised.
 
         """
 
@@ -202,11 +209,12 @@ class INotLazy(interface.Interface):
     on their ``control`` `inbox` when there are no other `messages` to for
     them.
 
-    .. note:: By default, all objects providing :class:`ICoroutine` are
-        presumptively `lazy`.  They need to provide this `interface` to
-        indicate otherwise.  This is more efficient and more natural for
-        `coroutines`.  It also more accurately distinguishes them from regular
-        `generators`.
+    .. note::
+
+      By default, all objects providing :class:`ICoroutine` are presumptively
+      `lazy`.  They need to provide this `interface` to indicate otherwise.
+      This is more efficient and more natural for `coroutines`.  It also more
+      accurately distinguishes them from regular `generators`.
 
     """
 
@@ -217,17 +225,17 @@ class IPostOfficeFactory(interface.Interface):
 
     """`Interface` for `callables` that return :class:`IPostOffice` objects."""
 
-    def __call__(link_ignores_duplicates=False, unlink_ignores_missing=False):
+    def __call__(link_ignores_duplicates=False,  # pragma: no branch
+      unlink_ignores_missing=False):
         """Return the desired `post office`.
 
-        :param link_ignores_duplicates: If :obj:`True`, the
+        :param bool link_ignores_duplicates: If :obj:`True`, the
           :meth:`IPostOffice.register` method becomes `idempotent` and will not
           raise an exception when adding an already added `link`.
-        :type link_ignores_duplicate: :class:`bool`
-        :param unlink_ignores_missing: If :obj:`True`, the
-          :meth:`*.unregister` method becomes `idempotent` and will not
-          raise an exception when removing a `link` that was not already added.
-        :type unlink_ignores_missing: :class:`bool`
+        :param bool unlink_ignores_missing: If :obj:`True`, the
+          :meth:`IPostOffice.unregister` method becomes `idempotent` and will
+          not raise an exception when removing a `link` that was not already
+          added.
 
         :returns: The desired `post office`.
         :rtype: :class:`IPostOffice`
@@ -249,7 +257,7 @@ class IPostOffice(interface.Interface):
 
     """
 
-    def register(first_link, *other_links):
+    def register(first_link, *other_links):  # pragma: no branch
         """Register `links` between `coroutines`.
 
         When a `source` `coroutine`'s `outbox` is linked to a `sink`
@@ -258,84 +266,86 @@ class IPostOffice(interface.Interface):
         `sink`'s `inbox`, where it can be later retrieved for delivery to the
         `sink` `coroutine`.
 
-        :param first_link: The first `link` to register.
-        :type first_link: 4-:class:`tuple`
-        :param other_links: Any other `links` to register.
-        :type other_links: :class:`tuple` of 4-:class:`tuple`\s
+        :param tuple first_link: The first `link` to register.
+        :param collections.Sequence other_links: Any other `links` to register.
 
-        Each link should be a 4-:class:`tuple` in the form of :samp:`({source},
+        Each link should be a 4-:obj:`tuple` in the form of :samp:`({source},
         {outbox}, {sink}, {inbox})`, where:
 
-        :param source: The `source` `coroutine` to link.
-        :type source: :class:`ICoroutine`
-        :param outbox: The `source`'s `outbox` to link.
-        :type outbox: :class:`unicode`
-        :param sink: The `sink` `coroutine` to link.
-        :type sink: :class:`ICoroutine`
-        :param inbox: The `sink`'s `inbox` to link.
-        :type sink_inbox: :class:`unicode`
+        :param m4us.core.interfaces.ICoroutine source: The `source` `coroutine`
+          to link.
+        :param unicode outbox: The `source`'s `outbox` to link.
+        :param m4us.core.interfaces.ICoroutine sink: The `sink` `coroutine` to
+          link.
+        :param unicode inbox: The `sink`'s `inbox` to link.
 
         :raises m4us.core.exceptions.LinkExistsError: If a `source`'s `outbox`
           is already linked to a `sink`'s `inbox`, unless the `post office` was
           created with ``link_ignores_duplicates=True``.
 
-        .. seealso:: The :class:`IPostOfficeFactory` `interface` for details on
-            the ``link_ignores_duplicates`` parameter.
+        .. seealso::
+
+          The :class:`IPostOfficeFactory` `interface` for details on the
+          ``link_ignores_duplicates`` parameter.
 
         """
 
-    def unregister(first_link, *other_links):
+    def unregister(first_link, *other_links):  # pragma: no branch
         """Unregister previously registered `links`.
 
-        This is the opposite of the :meth:`link` method.
+        This is the opposite of the :meth:`unregister` method.
 
-        :param first_link: The first `link` to unregister.
-        :type first_link: 4-:class:`tuple`
-        :param other_links: Any other `links` to unregister.
-        :type other_links: :class:`tuple` of 4-:class:`tuple`\s
+        :param tuple first_link: The first `link` to unregister.
+        :param collections.Sequence other_links: Any other `links` to
+          unregister.
 
-        Each link should be a 4-:class:`tuple` in the same format as defined in
-        the :meth:`link` method documentation.
+        Each link should be a 4-:obj:`tuple` in the same format as defined in
+        the :meth:`register` method documentation.
 
         :raises m4us.core.exceptions.NoLinkError: If a `link` was not
           previously registered, unless the `post office` was created with
           ``unlink_ignores_missing=True``.
 
-        .. note:: Unregistering one `link` should not affect any other links
-            involving the `source` `outbox` or the `sink` `inbox`.
+        .. note::
 
-        .. note:: Any outstanding messages in the `sink`'s `inbox` message
-            queue should still be kept for delivery.  The message queue should
-            only be removed after all outstanding `messages` have been
-            retrieved.
+          Unregistering one `link` should not affect any other links involving
+          the `source` `outbox` or the `sink` `inbox`.
 
-        .. seealso:: The :meth:`link` method for details on the format of a
-            link.
+        .. note::
 
-        .. seealso:: The :class:`IPostOfficeFactory` `interface` for details on
-            the ``unlink_ignores_missing`` parameter.
+          Any outstanding messages in the `sink`'s `inbox` message queue should
+          still be kept for delivery.  The message queue should only be removed
+          after all outstanding `messages` have been retrieved.
+
+        .. seealso::
+
+          The :meth:`register` method for details on the format of a link.
+
+        .. seealso::
+
+          The :class:`IPostOfficeFactory` `interface` for details on the
+          ``unlink_ignores_missing`` parameter.
 
         """
 
-    def post(source, outbox, message):
+    def post(source, outbox, message):  # pragma: no branch
         """Post a `message` from the `source` `outbox`.
 
         When a `message` is posted, it is automatically sent to the message
         queues of all linked `sink` `inboxes` for later retrieval and delivery.
 
-        :param source: The `source` `coroutine` that produced the `message`.
-        :type source: :class:`ICoroutine`
-        :param outbox: The `outbox` on which the `source` sent the `message`.
-        :type outbox: :class:`unicode`
+        :param m4us.core.interfaces.ICoroutine source: The `source` `coroutine`
+          that produced the `message`.
+        :param unicode outbox: The `outbox` on which the `source` sent the
+          `message`.
         :param message: The `message` that the `source` sent.
-        :type message: :class:`object`
 
         :raises m4us.core.exceptions.NoLinkError: If the `source` `outbox` has
           not already been registered as a `source` in a `link`.
 
         """
 
-    def retrieve(sink):
+    def retrieve(sink):  # pragma: no branch
         """Retrieve all outstanding `messages` for a `sink` `coroutine`.
 
         As `messages` are posted, they are accumulated in message queues based
@@ -346,18 +356,20 @@ class IPostOffice(interface.Interface):
         If there are no outstanding `messages` waiting in the message queue,
         then an empty iterable is returned.
 
-        :param sink: The `sink` `coroutine` for which to retrieve `messages`.
-        :type sink: :class:`ICoroutine`
+        :param m4us.core.interfaces.ICoroutine sink: The `sink` `coroutine` for
+          which to retrieve `messages`.
 
         :returns: All outstanding `messages` in the form of :samp:`({inbox},
           {message})`.
-        :rtype: iterable if 2-:class:`tuple`\s
+        :rtype: :class:`collections.Iterable`
 
         :raises m4us.core.exceptions.NotASinkError: If the given `coroutine` is
           not registered as a `sink` in any of the registered `links`.
 
-        .. note:: It is the responsibility of the caller to make sure all the
-            retrieved `messages` are delivered to the `sink` `coroutine`.
+        .. note::
+
+          It is the responsibility of the caller to make sure all the retrieved
+          `messages` are delivered to the `sink` `coroutine`.
 
         """
 
@@ -368,22 +380,19 @@ class ISchedulerFactory(interface.Interface):
 
     """`Interface` for `callables` that return :class:`IScheduler` objects."""
 
-    def __call__(post_office, add_ignores_duplicates=False,
-      remove_ignores_missing=False):
+    def __call__(post_office,  # pragma: no branch
+      add_ignores_duplicates=False, remove_ignores_missing=False):
         """Return the desired `scheduler`.
 
-        :param post_office: The `post office` through which to post and
-          retrieve `messages`.
-        :type post_office: :class:`IPostOffice`
-        :param add_ignores_duplicates: If :obj:`True`, the
+        :param m4us.core.interfaces.IPostOffice post_office: The `post office`
+          through which to post and retrieve `messages`.
+        :param bool add_ignores_duplicates: If :obj:`True`, the
           :meth:`IScheduler.register` method becomes `idempotent` and will not
           raise an exception when adding an already added `coroutine`.
-        :type add_ignores_duplicates: :class:`bool`
-        :param remove_ignores_missing: If :obj:`True`, the
+        :param bool remove_ignores_missing: If :obj:`True`, the
           :meth:`IScheduler.unregister` method becomes `idempotent` and will
           not raise an exception when removing a `coroutine` that was not
           already added.
-        :type remove_ignores_missing: :class:`bool`
 
         :returns: The desired `scheduler`.
         :rtype: :class:`IScheduler`
@@ -406,16 +415,16 @@ class IScheduler(interface.Interface):
 
     """
 
-    def register(first_coroutine, *other_coroutines):
+    def register(first_coroutine, *other_coroutines):  # pragma: no branch
         """Register one or more `coroutines` with the `scheduler`.
 
         In order for a `scheduler` to run a `coroutine`, it must first be added
         to (i.e. registered with) the `scheduler`.
 
-        :param first_coroutine: The first `coroutine` to add.
-        :type first_coroutine: :class:`ICoroutine`
-        :param other_coroutines: Any other `coroutines` to add.
-        :type other_coroutines: :class:`tuple` of :class:`ICoroutine`\s
+        :param m4us.core.interfaces.ICoroutine first_coroutine: The first
+          `coroutine` to add.
+        :param collections.Sequence other_coroutines: Any other `coroutines` to
+          add.
 
         :raises exceptions.TypeError: If any given argument does not provide or
           cannot be adapted to :class:`ICoroutine`.
@@ -423,38 +432,46 @@ class IScheduler(interface.Interface):
           has already been added, unless the `scheduler` was created with
           ``add_ignores_duplicates=True``.
 
-        .. note:: `Schedulers` are not *required* to preserve or guarantee any
-            particular order in which the `coroutines` will be run.  They may,
-            however, *choose* to do so, if desired.
+        .. note::
 
-        .. seealso:: The :class:`ISchedulerFactory` `interface` for details on
-            the ``add_ignores_duplicates`` parameter.
+          `Schedulers` are not *required* to preserve or guarantee any
+          particular order in which the `coroutines` will be run.  They may,
+          however, *choose* to do so, if desired.
+
+        .. seealso::
+
+          The :class:`ISchedulerFactory` `interface` for details on the
+          ``add_ignores_duplicates`` parameter.
 
         """
 
-    def unregister(first_coroutine, *other_coroutines):
+    def unregister(first_coroutine, *other_coroutines):  # pragma: no branch
         """Unregister one or more `coroutines` from the `scheduler`.
 
-        This is the opposite of the :meth:`add` method.
+        This is the opposite of the :meth:`register` method.
 
-        :param first_coroutine: The first `coroutine` to remove.
-        :type first_coroutine: :class:`ICoroutine`
-        :param other_coroutines: Any other `coroutines` to remove.
-        :type other_coroutines: :class:`tuple` of :class:`ICoroutine`\s
+        :param m4us.core.interfaces.ICoroutine first_coroutine: The first
+          `coroutine` to remove.
+        :param collections.Sequence other_coroutines: Any other `coroutines` to
+          remove.
 
         :raises m4us.core.exceptions.NotAddedError: If any given `coroutine` is
           not registered with the `scheduler`, unless the `scheduler` was
           created with ``remove_ignores_missing=True``.
 
-        .. note:: This method should also call each `coroutine`'s
-            :meth:`!close` method.
+        .. note::
 
-        .. seealso:: The :class:`ISchedulerFactory` `interface` for details on
-            the ``remove_ignores_missing`` parameter.
+          This method should also call each `coroutine`'s :meth:`!close`
+          method.
+
+        .. seealso::
+
+          The :class:`ISchedulerFactory` `interface` for details on the
+          ``remove_ignores_missing`` parameter.
 
         """
 
-    def step():
+    def step():  # pragma: no branch
         """Run one `coroutine`.
 
         This is the smallest unit of execution.  A single registered
@@ -493,14 +510,15 @@ class IScheduler(interface.Interface):
         should be sent to the `coroutine`.  Instead, an :class:`IShutdown`
         `message` should be sent to it's ``control`` `inbox` every time this
         method is called, until the `coroutine` exits (i.e. raises
-        :exc:`StopIteration`).  This allows `coroutines` to emit additional
-        `messages` before shutting down and ensures that `lazy` `coroutines`
-        always get enough `messages` to be able to shutdown properly.
+        :exc:`~exceptions.StopIteration`).  This allows `coroutines` to emit
+        additional `messages` before shutting down and ensures that `lazy`
+        `coroutines` always get enough `messages` to be able to shutdown
+        properly.
 
-        Finally, any `coroutine` that exits (i.e. raises :exc:`StopIteration`)
-        should be removed from any run queues and have its
-        :meth:`~m4us.core.interfaces.ICoroutine.close` method called.  After
-        that no `messages` should ever be sent to it again.
+        Finally, any `coroutine` that exits (i.e. raises
+        :exc:`~exceptions.StopIteration`) should be removed from any run queues
+        and have its :meth:`~m4us.core.interfaces.ICoroutine.close` method
+        called.  After that no `messages` should ever be sent to it again.
 
         :raises m4us.core.exceptions.NeverRunError: If a `coroutine` is `lazy`
           but the `post office` says it is not configured to receive any
@@ -510,18 +528,23 @@ class IScheduler(interface.Interface):
           :class:`IShutdown` `messages` are expected to be cascaded (even from
           `consumers`), so they do not cause the exception to be re-raised.
 
-        .. note:: At least one `coroutine` is expected to be added before
-            calling this method.  It is an error to do otherwise.
+        .. note::
 
-        .. seealso:: :class:`INotLazy` for details about the non-`lazy`
-            `coroutines`.
+          At least one `coroutine` is expected to be added before calling this
+          method.  It is an error to do otherwise.
 
-        .. seealso:: :meth:`IPostOffice.post` for details on the
-            :class:`~m4us.core.exceptions.NoLinkError` exception.
+        .. seealso::
+
+          :class:`INotLazy` for details about the non-`lazy` `coroutines`.
+
+        .. seealso::
+
+          :meth:`IPostOffice.post` for details on the
+          :class:`~m4us.core.exceptions.NoLinkError` exception.
 
         """
 
-    def cycle():
+    def cycle():  # pragma: no branch
         """Cycle once through the main loop, running all eligible `coroutines`.
 
         `Schedulers` represent the main execution loop.  This method triggers
@@ -529,13 +552,14 @@ class IScheduler(interface.Interface):
         method as many times as is appropriate.  Ideally all registered
         `coroutines` should have a chance to run.
 
-        .. seealso:: The :meth:`step` method for details on how `coroutines`
-            are run and on the exceptions that this method can raise as a
-            result.
+        .. seealso::
+
+          The :meth:`step` method for details on how `coroutines` are run and
+          on the exceptions that this method can raise as a result.
 
         """
 
-    def run(cycles=None):
+    def run(cycles=None):  # pragma: no branch
         """Start the `scheduler`, running all registered `coroutines`.
 
         This is the main execution loop.
@@ -544,15 +568,18 @@ class IScheduler(interface.Interface):
           One cycle is defined as a one call to the :meth:`cycle` method.  If
           :obj:`None` or not specified, then this method should run until all
           registered `coroutines` have shutdown (i.e. raised
-          :exc:`StopIteration`).
-        :type cycles: :class:`int` or :obj:`None`
+          :exc:`~exceptions.StopIteration`).
+        :type cycles: :obj:`int` or :obj:`None`
 
-        .. note:: If *cycles* is specified, it is expected that subsequent
-            calls to this method should continue from where the last call left
-            off.
+        .. note::
 
-        .. seealso:: The :meth:`cycle` method for details on what a single
-            cycle entails and what exceptions may be raised as a result.
+          If *cycles* is specified, it is expected that subsequent calls to
+          this method should continue from where the last call left off.
+
+        .. seealso::
+
+          The :meth:`cycle` method for details on what a single cycle entails
+          and what exceptions may be raised as a result.
 
         """
 
@@ -563,13 +590,13 @@ class IContainerFactory(interface.Interface):
 
     """`Interface` for `callables` that return :class:`IContainer` objects."""
 
-    def __call__(*args, **kwargs):
+    def __call__(*args, **kwargs):  # pragma: no branch
         """Return the desired container.
 
-        :param args: Any positional arguments that the `factory` may accept.
-        :type args: :class:`tuple`
-        :param kwargs: Any keyword arguments that the `factory` may accept.
-        :type kwargs: :class:`dict`
+        :param collections.Sequence args: Any positional arguments that the
+          `factory` may accept.
+        :param collections.Mapping kwargs: Any keyword arguments that the
+          `factory` may accept.
 
         :returns: The desired container.
         :rtype: :class:`IContainer`
@@ -588,23 +615,24 @@ class IContainer(interface.Interface):
     the `links` that connect them both to each other and to the container
     itself, if appropriate.
 
-    All containers should calculate and provide :attr:`~IContainer.coroutines`
-    and :attr:`~IContainer.links` attributes before they are used. The contents
-    of :attr:`~IContainer.coroutines` should be able to be passed to the
+    All containers should calculate and provide :attr:`IContainer.coroutines`
+    and :attr:`IContainer.links` attributes before they are used. The contents
+    of :attr:`IContainer.coroutines` should be able to be passed to the
     appropriate :meth:`IScheduler.register` method and the contents of
-    :attr:`~IContainer.links` should be able to be passed to the appropriate
-    :meth:`~IPostOffice.register` method.
+    :attr:`IContainer.links` should be able to be passed to the appropriate
+    :meth:`IPostOffice.register` method.
 
     Additionally, containers can contain other :class:`IContainer` objects, in
     other words other containers.  In such a case,
-    :attr:`~IContainer.coroutines` and :attr:`~IContainer.links` should include
+    :attr:`IContainer.coroutines` and :attr:`IContainer.links` should include
     the `coroutines` and `links` from the sub-containers, excluding any
     duplicates from the other `coroutines` and `links` in the parent container.
 
-    .. note:: Containers will usually provide :class:`ICoroutine` as well, but
-        that is not strictly required by this interface.  The calculation and
-        use of the above-mentioned two attributes makes it not a strict
-        requirement.
+    .. note::
+
+      Containers will usually provide :class:`ICoroutine` as well, but that is
+      not strictly required by this interface.  The calculation and use of the
+      above-mentioned two attributes makes it not a strict requirement.
 
     """
 
@@ -617,10 +645,12 @@ class IContainer(interface.Interface):
         The contained `coroutines` can be added to the `scheduler` with code
         similar to :samp:`{scheduler}.add(*{container}.coroutines)`.
 
-        :type: Immutable sequence of :class:`ICoroutine`\s
+        :type: :class:`collections.Sequence`
 
-        .. seealso:: :meth:`IScheduler.register` for details about adding
-            `coroutines` to `schedulers`.
+        .. seealso::
+
+          :meth:`IScheduler.register` for details about adding `coroutines` to
+          `schedulers`.
 
         """)
 
@@ -634,10 +664,12 @@ class IContainer(interface.Interface):
         `post office` with code similar to
         :samp:`{post_office}.register(*{container}.links)`.
 
-        :type: Immutable sequence of 4-:class:`tuple`\s
+        :type: :class:`collections.Sequence`
 
-        .. seealso:: :meth:`IPostOffice.register` for details about adding
-            `links` to `post offices`.
+        .. seealso::
+
+          :meth:`IPostOffice.register` for details about adding `links` to
+          `post offices`.
 
         """)
 
