@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,13 +30,13 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core import interfaces
@@ -50,52 +50,49 @@ from m4us.core import interfaces
 
 #---Classes--------------------------------------------------------------------
 
+@interface.implementer(interfaces.IMessage)
+@interface.provider(interfaces.IMessageFactory)
 class Message(object):
 
     """Base class for special `messages` passed between `coroutines`.
 
-    :Implements: :class:`~m4us.core.interfaces.IMessage`
-    :Provides: :class:`~m4us.core.interfaces.IMessageFactory`
+    :implements: :class:`m4us.core.interfaces.IMessage`
+    :provides: :class:`m4us.core.interfaces.IMessageFactory`
 
     """
 
     ## pylint: disable=R0903
 
-    interface.implements(interfaces.IMessage)
-    interface.classProvides(interfaces.IMessageFactory)
-
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
 
 
+## pylint: disable=R0903
+@interface.implementer(interfaces.IShutdown)
+@interface.provider(interfaces.IMessageFactory)
 class Shutdown(Message):
 
     """`Message` that indicates that a `coroutine` should shutdown.
 
-    :Implements: :class:`~m4us.core.interfaces.IShutdown`
-    :Provides: :class:`~m4us.core.interfaces.IMessageFactory`
+    :implements: :class:`m4us.core.interfaces.IShutdown`
+    :provides: :class:`m4us.core.interfaces.IMessageFactory`
 
     """
-
-    ## pylint: disable=R0903
-
-    interface.implements(interfaces.IShutdown)
-    interface.classProvides(interfaces.IMessageFactory)
+## pylint: enable=R0903
 
 
+## pylint: disable=R0903
+@interface.implementer(interfaces.IProducerFinished)
+@interface.provider(interfaces.IMessageFactory)
 class ProducerFinished(Message):
 
     """`Message` that indicates that a `producer` has finished.
 
-    :Implements: :class:`~m4us.core.interfaces.IProducerFinished`
-    :Provides: :class:`~m4us.core.interfaces.IMessageFactory`
+    :implements: :class:`m4us.core.interfaces.IProducerFinished`
+    :provides: :class:`m4us.core.interfaces.IMessageFactory`
 
     """
-
-    ## pylint: disable=R0903
-
-    interface.implements(interfaces.IProducerFinished)
-    interface.classProvides(interfaces.IMessageFactory)
+## pylint: enable=R0903
 
 
 #---Module initialization------------------------------------------------------
