@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -36,13 +36,13 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core import exceptions, interfaces
@@ -56,6 +56,8 @@ from m4us.core import exceptions, interfaces
 
 #---Classes--------------------------------------------------------------------
 
+@interface.implementer(interfaces.IPostOffice)
+@interface.provider(interfaces.IPostOfficeFactory)
 class PostOffice(object):
 
     """The standard `post office` class used for `message` routing.
@@ -64,14 +66,11 @@ class PostOffice(object):
     :class:`~m4us.core.interfaces.IPostOffice`.  Unless you have a special
     need, this is this `post office` you want to use.
 
-    :Implements: :class:`~m4us.core.interfaces.IPostOffice`
-    :Provides: :class:`~m4us.core.interfaces.IPostOfficeFactory`
+    :implements: :class:`m4us.core.interfaces.IPostOffice`
+    :provides: :class:`m4us.core.interfaces.IPostOfficeFactory`
 
     """
 
-    interface.implements(interfaces.IPostOffice)
-    interface.classProvides(interfaces.IPostOfficeFactory)
-
     def __init__(self, link_ignores_duplicates=False,
       unlink_ignores_missing=False):
         """See class docstring for this method's documentation."""
@@ -87,8 +86,10 @@ class PostOffice(object):
     def register(self, first_link, *other_links):
         """Register `links` between `coroutines`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IPostOffice` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IPostOffice` `interface` for
+          details about this method.
 
         """
         for source, outbox, sink, inbox in (first_link,) + other_links:
@@ -106,8 +107,10 @@ class PostOffice(object):
     def unregister(self, first_link, *other_links):
         """Unregister previously registered `links`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IPostOffice` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IPostOffice` `interface` for
+          details about this method.
 
         """
         for source, outbox, sink, inbox in (first_link,) + other_links:
@@ -130,8 +133,10 @@ class PostOffice(object):
     def post(self, source, outbox, message):
         """Post a `message` from the `source` `outbox`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IPostOffice` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IPostOffice` `interface` for
+          details about this method.
 
         """
         source_outbox = (source, outbox)
@@ -147,8 +152,10 @@ class PostOffice(object):
     def retrieve(self, sink):
         """Retrieve all outstanding `messages` for a `sink` `coroutine`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IPostOffice` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IPostOffice` `interface` for
+          details about this method.
 
         """
         try:
