@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -37,15 +37,15 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 import collections
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from  . import messages, utils, exceptions, interfaces
@@ -59,6 +59,8 @@ from  . import messages, utils, exceptions, interfaces
 
 #---Classes--------------------------------------------------------------------
 
+@interface.implementer(interfaces.IScheduler)
+@interface.provider(interfaces.ISchedulerFactory)
 class Scheduler(object):
 
     """The standard `scheduler` class to run `coroutines`.
@@ -67,23 +69,22 @@ class Scheduler(object):
     :class:`~m4us.core.interfaces.IScheduler`.  Unless you have a special need,
     this is this probably `scheduler` you want to use.
 
-    :param post_office: The `post office` object to use for `message` routing.
-    :type post_office: :class:`~m4us.core.interfaces.IPostOffice`
+    :param m4us.core.interfaces.IPostOffice post_office: The `post office`
+      object to use for `message` routing.
 
     :raises exceptions.TypeError: If the given `post office` does not provide
       or cannot be adapted to :class:`~m4us.core.interfaces.IPostOffice`.
 
-    :Implements: :class:`~m4us.core.interfaces.IScheduler`
-    :Provides: :class:`~m4us.core.interfaces.ISchedulerFactory`
+    :implements: :class:`m4us.core.interfaces.IScheduler`
+    :provides: :class:`m4us.core.interfaces.ISchedulerFactory`
 
-    .. seealso:: The :class:`~m4us.core.interfaces.IPostOffice` `interface` for
-        details on `post offices`.
+    .. seealso::
+
+      The :class:`~m4us.core.interfaces.IPostOffice` `interface` for details on
+      `post offices`.
 
     """
 
-    interface.implements(interfaces.IScheduler)
-    interface.classProvides(interfaces.ISchedulerFactory)
-
     def __init__(self, post_office, add_ignores_duplicates=False,
       remove_ignores_missing=False):
         """See class docstring for this method's documentation."""
@@ -100,8 +101,10 @@ class Scheduler(object):
     def register(self, first_coroutine, *other_coroutines):
         """Register one or more `coroutines` with the `scheduler`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IScheduler` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IScheduler` `interface` for details
+          about this method.
 
         """
         for coroutine in (first_coroutine,) + other_coroutines:
@@ -118,8 +121,10 @@ class Scheduler(object):
     def unregister(self, first_coroutine, *other_coroutines):
         """Unregister one or more `coroutines` from the `scheduler`.
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IScheduler` `interface`
-            for details about this method.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IScheduler` `interface` for details
+          about this method.
 
         """
         for coroutine in (first_coroutine,) + other_coroutines:
@@ -136,14 +141,18 @@ class Scheduler(object):
     def step(self):
         """Run one `coroutine`.
 
-        .. note:: `Coroutines` are run in a `round-robin`_ style, in the order
-            that they have been added.  `Coroutines` should not, however, rely
-            on this implementation detail.
+        .. note::
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IScheduler` `interface`
-            for details about this method.
+          `Coroutines` are run in a `round-robin`_ style, in the order that
+          they have been added.  `Coroutines` should not, however, rely on this
+          implementation detail.
 
-        .. _`round-robin`: http://en.wikipedia.org/wiki/Round-robin_scheduling
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IScheduler` `interface` for details
+          about this method.
+
+        .. _round-robin: http://en.wikipedia.org/wiki/Round-robin_scheduling
 
         """
         # Note: It is assumed that either the original coroutine can store it's
@@ -199,17 +208,17 @@ class Scheduler(object):
         `coroutine` is not `lazy`, then only a :obj:`None` ``control``
         `message` will be in the returned interable.
 
-        :param original_coroutine: The (unadapted) `coroutine` for which to
-          check for `messages`.  This should be the `coroutine` object as it
-          was registered with the `post office`, not an adapter or anything.
-        :type original_coroutine: :class:`~m4us.core.interfaces.ICoroutine`
+        :param m4us.core.interfaces.ICoroutine original_coroutine: The
+          (unadapted) `coroutine` for which to check for `messages`.  This
+          should be the `coroutine` object as it was registered with the `post
+          office`, not an adapter or anything.
 
         :returns: An iterable of `inbox` messages to be delivered to the given
           `coroutine`.
-        :rtype: *iterable*
+        :rtype: :class:`collections.Iterable`
 
         :raises m4us.core.exceptions.NeverRunError: If the `post office` raises
-          :exc:`~m4us.core.exceptions.NotASinkError` and the `coroutine` is
+          :exc:`m4us.core.exceptions.NotASinkError` and the `coroutine` is
           `lazy`.
 
         """
@@ -245,17 +254,22 @@ class Scheduler(object):
     def cycle(self):
         """Cycle once through the main loop, running all eligible `coroutines`.
 
-        .. warning:: The current implementation of this method can handle a
-            shrinking run queue due to `coroutines` shutting down, but it has
-            not yet been designed to handle the dynamic adding or removing of
-            `coroutines` within a the cycle execution.  It's behaviour in those
-            situations is currently undefined.
+        .. warning::
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IScheduler` `interface`
-            for details about this method.
+          The current implementation of this method can handle a shrinking run
+          queue due to `coroutines` shutting down, but it has not yet been
+          designed to handle the dynamic adding or removing of `coroutines`
+          within a the cycle execution.  It's behaviour in those situations is
+          currently undefined.
 
-        .. seealso:: The :meth:`step` method for details how the `coroutines`
-            are run.
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IScheduler` `interface` for details
+          about this method.
+
+        .. seealso::
+
+          The :meth:`step` method for details how the `coroutines` are run.
 
         """
         # TODO: Handle changes in _run_queue length?
@@ -265,18 +279,25 @@ class Scheduler(object):
     def run(self, cycles=None):
         """Start the `scheduler`, running all registered `coroutines`.
 
-        .. warning:: If *cycles* is not specified and any of the `coroutines`
-            do not cascade :class:`~m4us.core.interfaces.IShutdown` `messages`
-            or shutdown properly, then this method will likely loop forever.
+        .. warning::
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IScheduler` `interface`
-            for details about this method.
+          If *cycles* is not specified and any of the `coroutines` do not
+          cascade :class:`~m4us.core.interfaces.IShutdown` `messages` or
+          shutdown properly, then this method will likely loop forever.
 
-        .. seealso:: The :meth:`cycle` method for details how the `coroutines`
-            are run.
+        .. seealso::
 
-        .. seealso:: The :class:`~m4us.core.interfaces.IShutdown` `interface`
-            for details on shutdown messages.
+          The :class:`~m4us.core.interfaces.IScheduler` `interface` for details
+          about this method.
+
+        .. seealso::
+
+          The :meth:`cycle` method for details how the `coroutines` are run.
+
+        .. seealso::
+
+          The :class:`~m4us.core.interfaces.IShutdown` `interface` for details
+          on shutdown messages.
 
         """
         if cycles is not None:
