@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,12 +30,14 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
 ## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
+## pylint: enable=F0401
 ## pylint: enable=E0611
 
 #---  Project imports
@@ -65,11 +67,10 @@ def accumulator(message, results_list):
 
 #---Classes--------------------------------------------------------------------
 
+@interface.implementer(m4us.INotLazy)
+@interface.provider(m4us.ICoroutineFactory)
 class Counter(m4us.Component):
 
-    interface.implements(m4us.INotLazy)
-    interface.classProvides(m4us.ICoroutineFactory)
-
     def __init__(self, max_count, **kwargs):
         m4us.Component.__init__(self, max_count=max_count, **kwargs)
 
@@ -80,10 +81,9 @@ class Counter(m4us.Component):
         yield 'signal', m4us.ProducerFinished()
 
 
+@interface.provider(m4us.ICoroutineFactory)
 class Doubler(m4us.Component):
 
-    interface.classProvides(m4us.ICoroutineFactory)
-
     def _main(self):
         inbox, message = (yield)
         while True:
@@ -93,10 +93,9 @@ class Doubler(m4us.Component):
             inbox, message = (yield 'outbox', message * 2)
 
 
+@interface.provider(m4us.ICoroutineFactory)
 class Accumulator(m4us.Component):
 
-    interface.classProvides(m4us.ICoroutineFactory)
-
     def __init__(self, **kwargs):
         self.results_list = []
         m4us.Component.__init__(self, **kwargs)
