@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 import glob
@@ -43,11 +43,10 @@ import contextlib
 import unittest2
 import decorator
 import pkg_resources
-## pylint: disable=E0611
-from zope import interface
 ## pylint: disable=F0401
+from zope import interface
 from zope.interface import verify, exceptions
-## pylint: enable=E0611, F0401
+## pylint: enable=F0401
 from unittest2 import loader, runner
 
 #---  Project imports
@@ -135,8 +134,10 @@ class _PEP8Meta(type):
     read by the meta-class and removed from the actual class before it is
     created.
 
-    .. note:: This meta-class does not affect sub-classes, only the class on
-        which it was directly applied.
+    .. note::
+
+      This meta-class does not affect sub-classes, only the class on which it
+      was directly applied.
 
     """
 
