@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,16 +30,15 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
 import unittest2
-## pylint: disable=E0611
-from zope import interface
 ## pylint: disable=F0401
+from zope import interface
 from zope.interface import verify
-## pylint: enable=E0611, F0401
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core.tests import support, test_coroutines
@@ -53,10 +52,9 @@ from m4us.core.tests import support, test_coroutines
 def make_basic_component_class():
     from m4us.core import components, interfaces
 
+    @interface.provider(interfaces.ICoroutineFactory)
     class BasicComponent(components.Component):
 
-        interface.classProvides(interfaces.ICoroutineFactory)
-
         def _main(self):
             return test_coroutines.plain_coroutine()
 
@@ -69,11 +67,15 @@ class ComponentShouldProvideICoroutine(
   test_coroutines.CoroutineShouldProvideICoroutine,
   support.ClassShouldProvideAndImplementInterface):
 
+    ## pylint: disable=W0223
+
     pass
 
 
 class ComponentShouldAcceptKeywordArguments(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def test_it_should_accept_keyword_arguments(self):
         with self.assert_not_raises(TypeError):
             self._call_sut(foo='bar', bat='baz')
@@ -89,6 +91,8 @@ class ComponentShouldAcceptKeywordArguments(support.CommonTestBase):
 class ComponentShouldSupportAnInternalCoroutine(
   test_coroutines.CoroutineTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_icoroutine_interface(self):
         from m4us.core import interfaces
         return interfaces.ICoroutine
