@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -32,7 +32,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 import inspect
@@ -41,9 +41,9 @@ import types
 #---  Third-party imports
 import unittest2
 import mock
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core.tests import support
@@ -135,6 +135,8 @@ class DummyIterable(object):
 
 class CoroutineTestBase(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_messages(self):
         message1 = ('inbox', 'Hello')
         message2 = ('inbox', 'Message 2')
@@ -182,6 +184,8 @@ class BasicMessagesMixin(object):
 
 class CoroutineShouldProvideICoroutine(support.ObjectShouldProvideInterface):
 
+    ## pylint: disable=W0223
+
     def _get_sut_interfaces(self):
         from m4us.core import interfaces
         return (interfaces.ICoroutineFactory,)
@@ -193,6 +197,8 @@ class CoroutineShouldProvideICoroutine(support.ObjectShouldProvideInterface):
 
 class CoroutineShouldProvideINotLazy(support.ObjectShouldProvideInterface):
 
+    ## pylint: disable=W0223
+
     def _get_result_interfaces(self):
         from m4us.core import interfaces
         return (interfaces.INotLazy,)
@@ -202,6 +208,8 @@ class CoroutineShouldProvideINotLazy(support.ObjectShouldProvideInterface):
 
 class CoroutineShouldAcceptAndEmitMessages(CoroutineTestBase):
 
+    ## pylint: disable=W0223
+
     def test_it_should_accept_and_emit_messages(self):
         coroutine = self._call_sut()
         messages = self._get_messages()
@@ -218,6 +226,8 @@ class CoroutineShouldAcceptAndEmitMessages(CoroutineTestBase):
 
 class CoroutineShouldSupportThrowingExceptions(CoroutineTestBase):
 
+    ## pylint: disable=W0223
+
     def test_throw_should_raise_unhandled_thrown_exception(self):
         coroutine = self._call_sut()
         exception = self._get_exception()
@@ -227,6 +237,8 @@ class CoroutineShouldSupportThrowingExceptions(CoroutineTestBase):
 
 class CoroutineShouldSupportDelayedExceptions(CoroutineTestBase):
 
+    ## pylint: disable=W0223
+
     def test_throw_should_return_yielded_results(self):
         coroutine = self._call_sut()
         primer_message = self._get_messages()[0]
@@ -238,6 +250,8 @@ class CoroutineShouldSupportDelayedExceptions(CoroutineTestBase):
 
 class CoroutineShouldSupportBeingClosed(CoroutineTestBase):
 
+    ## pylint: disable=W0223
+
     def test_send_should_raise_stopiteration_if_coroutine_is_closed(self):
         coroutine = self._call_sut()
         coroutine.close()
@@ -260,6 +274,8 @@ class CoroutineShouldSupportBeingClosed(CoroutineTestBase):
 
 class CoroutineShouldRespondToShutdownMessages(CoroutineTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_ishutdown_interface(self):
         from m4us.core import interfaces
         return interfaces.IShutdown
