@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
@@ -50,6 +50,8 @@ from m4us.core.tests import support
 
 class ExceptionShouldHaveADefaultMessage(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def test_it_should_have_a_default_message(self):
         exception = self._call_sut()
         self.assert_true(hasattr(exception, '_message'))
@@ -58,6 +60,8 @@ class ExceptionShouldHaveADefaultMessage(support.CommonTestBase):
 
 class ExceptionShouldAcceptPositionalArguments(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def test_it_should_accept_a_positional_argument(self):
         exception_class = self._get_sut()
         required_kwargs = self._get_required_kwargs()
@@ -78,6 +82,8 @@ class ExceptionShouldAcceptPositionalArguments(support.CommonTestBase):
 
 class ExceptionShouldAcceptKeywordArguments(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def test_it_should_accept_keyword_arguments(self):
         exception_class = self._get_sut()
         required_kwargs = self._get_required_kwargs()
@@ -93,6 +99,8 @@ class ExceptionShouldAcceptKeywordArguments(support.CommonTestBase):
 
 class ExceptionShouldProvideAFormattedMessage(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def test_str_should_return_valid_error_message(self):
         exception = self._call_sut()
         with self.assert_not_raises(KeyError):
