@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
@@ -51,6 +51,8 @@ from m4us.core.tests import support
 class MessageShouldProvideIMessage(
   support.ClassShouldProvideAndImplementInterface):
 
+    ## pylint: disable=W0223
+
     def _get_sut_interfaces(self):
         from m4us.core import interfaces
         return (interfaces.IMessageFactory,)
@@ -62,6 +64,8 @@ class MessageShouldProvideIMessage(
 
 class MessageShouldAcceptKeywordArguments(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def test_it_should_set_keyword_arguments_as_attributes(self):
         custom_kwargs = dict(foo='bar', bat='baz')
         kwargs = self._get_required_kwargs()
