@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
@@ -51,6 +51,8 @@ from m4us.core.tests import support
 
 class PostOfficeTestBase(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_nolinkerror_class(self):
         from m4us.core import exceptions
         return exceptions.NoLinkError
@@ -82,6 +84,8 @@ class PostOfficeTestBase(support.CommonTestBase):
 class PostOfficeShouldProvideIPostOffice(
   support.ClassShouldProvideAndImplementInterface):
 
+    ## pylint: disable=W0223
+
     def _get_sut_interfaces(self):
         from m4us.core import interfaces
         return (interfaces.IPostOfficeFactory,)
@@ -101,6 +105,8 @@ class PostOfficeShouldProvideIPostOffice(
 
 class PostOfficeShouldSupportAddingLinks(PostOfficeTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_linkexistserror_class(self):
         from m4us.core import exceptions
         return exceptions.LinkExistsError
@@ -134,6 +140,8 @@ class PostOfficeShouldSupportAddingLinks(PostOfficeTestBase):
 
 class PostOfficeShouldSupportRemovingLinks(PostOfficeTestBase):
 
+    ## pylint: disable=W0223
+
     def test_unlink_should_accept_a_single_link_argument(self):
         post_office = self._call_sut()
         link = self._make_mock_link()
@@ -176,6 +184,8 @@ class PostOfficeShouldSupportRemovingLinks(PostOfficeTestBase):
 
 class PostOfficeShouldSupportPostingMessages(PostOfficeTestBase):
 
+    ## pylint: disable=W0223
+
     def test_post_should_accept_message_if_source_outbox_matches_a_link(self):
         message = 'Some message'
         post_office = self._call_sut()
@@ -198,6 +208,8 @@ class PostOfficeShouldSupportPostingMessages(PostOfficeTestBase):
 
 class PostOfficeShouldSupportRetrievingMessages(PostOfficeTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_notasinkerror_class(self):
         from m4us.core import exceptions
         return exceptions.NotASinkError
