@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,15 +30,15 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
 import unittest2
 import mock
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 
 #---  Project imports
@@ -55,6 +55,8 @@ from m4us.core.tests import support
 
 class SchedulerTestBase(support.CommonTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_ipostoffice_interface(self):
         from m4us.core import interfaces
         return interfaces.IPostOffice
@@ -131,6 +133,8 @@ class SchedulerTestBase(support.CommonTestBase):
 class SchedulerShouldProvideIScheduler(
   support.ClassShouldProvideAndImplementInterface):
 
+    ## pylint: disable=W0223
+
     def _get_sut_interfaces(self):
         from m4us.core import interfaces
         return (interfaces.ISchedulerFactory,)
@@ -164,6 +168,8 @@ class SchedulerShouldProvideIScheduler(
 
 class SchedulerShouldSupportAddingCoroutines(SchedulerTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_duplicateerror_class(self):
         from m4us.core import exceptions
         return exceptions.DuplicateError
@@ -202,6 +208,8 @@ class SchedulerShouldSupportAddingCoroutines(SchedulerTestBase):
 
 class SchedulerShouldSupportRemovingCoroutines(SchedulerTestBase):
 
+    ## pylint: disable=W0223
+
     def _get_notaddederror_class(self):
         from m4us.core import exceptions
         return exceptions.NotAddedError
@@ -245,6 +253,8 @@ class SchedulerShouldSupportRemovingCoroutines(SchedulerTestBase):
 
 class SchedulerShouldPostAndDeliverMessages(SchedulerTestBase):
 
+    ## pylint: disable=W0223
+
     def test_step_should_send_messages_to_the_post_office(self):
         post_office = self._make_mock_post_office()
         scheduler = self._call_sut(post_office)
@@ -291,6 +301,8 @@ class SchedulerShouldPostAndDeliverMessages(SchedulerTestBase):
 
 class SchedulerShouldBreakOnInvalidConfiguration(SchedulerTestBase):
 
+    ## pylint: disable=W0223
+
     def test_step_should_raise_neverrunerror_if_not_a_sink_and_lazy(self):
         scheduler = self._call_sut()
         coroutine = self._make_mock_coroutine(lazy=True)
@@ -314,6 +326,8 @@ class SchedulerShouldBreakOnInvalidConfiguration(SchedulerTestBase):
 
 class SchedulerShouldHandleCoroutineShutdowns(SchedulerTestBase):
 
+    ## pylint: disable=W0223
+
     def test_step_should_drop_unpostable_ishutdown_messages(self):
         post_office = self._make_mock_post_office()
         no_link_error_class = self._get_nolinkerror_class()
@@ -367,6 +381,8 @@ class SchedulerShouldHandleCoroutineShutdowns(SchedulerTestBase):
 
 class SchedulerShouldSupportCyclingAFixedNumberOfLoops(SchedulerTestBase):
 
+    ## pylint: disable=W0223
+
     def test_cycle_should_run_once_through_all_coroutines(self):
         scheduler = self._call_sut()
         coroutines = self._make_mock_coroutines(5)
@@ -393,6 +409,8 @@ class SchedulerShouldSupportCyclingAFixedNumberOfLoops(SchedulerTestBase):
 class SchedulerShouldSupportRunningUntilAllCoroutinesShutdown(
   SchedulerTestBase):
 
+    ## pylint: disable=W0223
+
     def test_run_should_run_until_all_coroutines_terminate(self):
         # Note: This test kind of relies on scheduler.run() hanging on failure.
         #       As such, it's not a great implementation of the test.  A better
