@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 import types
@@ -74,18 +74,15 @@ def _is_private_object(object_name, object_, excludes=_DEFAULT_NAME_EXCLUDES):
       * It is a module, or
       * It is from the *__future__* or *future_builtins* modules.
 
-    :param object_name: The name of the object to check.
-    :type object_name: :class:`str` or :class:`unicode`
+    :param basestring object_name: The name of the object to check.
     :param object_: The object to check.
-    :type object_: :class:`object`
-    :param excludes: A sequence of object names to always consider as private.
-      The default just includes the names from *future_builtins* that original
-      elsewhere.
-    :type excludes: *sequence* of :class:`str` or :class:`unicode`
+    :param collections.Sequence excludes: A sequence of object names to always
+      consider as private. The default just includes the names from
+      *future_builtins* that original elsewhere.
 
     :returns: :obj:`True` if the object is considered non-public, :obj:`False`
       otherwise.
-    :rtype: :class:`bool`
+    :rtype: :obj:`bool`
 
     """
     return (
@@ -111,13 +108,13 @@ def _public_object_names(namespace, excludes=_DEFAULT_NAME_EXCLUDES):
     >>> for name in _public_object_names(vars(somemodule)):
     >>>     print(name)
 
-    :param namespace: The namesapce in which to search for objects.
-    :type namespace: :class:`dict`
-    :param excludes: A sequence of object names to always exclude.
-    :type excludes: *sequence* of :class:`str` or :class:`unicode`
+    :param collections.Mapping namespace: The namesapce in which to search for
+      objects.
+    :param collections.Sequence excludes: A sequence of object names to always
+      exclude.
 
     :returns: An iterator of public object names from the given namespace.
-    :rtype: :class:`~types.GeneratorType`
+    :rtype: :data:`types.GeneratorType`
 
     """
     excludes = set(excludes)
@@ -140,28 +137,31 @@ def easy_link(first_coroutine, second_coroutine, *other_coroutines):
 
     The resulting `links` can then be passed to a `post office`.
 
-    :param first_coroutine: A minimum of two `coroutines` are required. This is
-      the first one.
-    :type first_coroutine: :class:`~m4us.core.interfaces.ICoroutine`
-    :param second_coroutine: The second `coroutine`.
-    :type second_coroutine: :class:`~m4us.core.interfaces.ICoroutine`
-    :param other_coroutines: Any other `coroutines` to `link` after the second
-      one.
-    :type other_coroutines: :class:`tuple` of
-      :class:`~m4us.core.interfaces.ICoroutine`
+    :param m4us.core.interfaces.ICoroutine first_coroutine: A minimum of two
+      `coroutines` are required. This is the first one.
+    :param m4us.core.interfaces.ICoroutine second_coroutine: The second
+      `coroutine`.
+    :param collections.Sequence other_coroutines: Any other `coroutines` to
+      `link` after the second one.
 
     :returns: A set of `mailbox` `links` to be given to a `post office`.
-    :rtype: :class:`set` of 4-:class:`tuple`\s
+    :rtype: :class:`set`
 
-    .. note:: Normally one would just use the
-        :class:`~m4us.core.containers.Pipeline` class, but this provides just
-        the `links`, which could be useful to other `container` classes.
+    .. note::
 
-    .. seealso:: The :class:`~m4us.core.interfaces.IPostOffice` `interface` for
-        more information on `links`, `mailboxes` and `post offices`.
+      Normally one would just use the :class:`~m4us.core.containers.Pipeline`
+      class, but this provides just the `links`, which could be useful to other
+      `container` classes.
 
-    .. seealso:: The :class:`~m4us.core.containers.Pipeline` class for the
-        normal way to construct `coroutine` `pipelines`.
+    .. seealso::
+
+      The :class:`~m4us.core.interfaces.IPostOffice` `interface` for more
+      information on `links`, `mailboxes` and `post offices`.
+
+    .. seealso::
+
+      The :class:`~m4us.core.containers.Pipeline` class for the normal way to
+      construct `coroutine` `pipelines`.
 
     """
     sources = (first_coroutine, second_coroutine) + other_coroutines[:-1]
@@ -181,20 +181,17 @@ def is_shutdown(inbox, message, expected_inbox='control'):
     `Coroutines` are expected to shutdown when they receive a shutdown
     `message`.  This is a convenience function that returns :obj:`True` if
     `inbox` is ``control`` (by default) and the `message` object provides or is
-    adaptable to :class:`~m4us.interfaces.IShutdown`.
+    adaptable to :class:`~m4us.core.interfaces.IShutdown`.
 
-    :param inbox: The `inbox` in which with `message` was received.
-    :type inbox: :class:`unicode`
+    :param unicode inbox: The `inbox` in which with `message` was received.
     :param message: The `message` object that was received.
-    :type message: any
-    :param expected_inbox: The `inbox` in which
-      :class:`~m4us.interfaces.IShutdown` `messages` are expected.  This
+    :param unicode expected_inbox: The `inbox` in which
+      :class:`~m4us.core.interfaces.IShutdown` `messages` are expected.  This
       parameter lets the default be overridden.
-    :type expected_inbox: :class:`unicode`
 
     :returns: :obj:`True` if the `message` signals that the `coroutine` should
       shutdown, :obj:`False` otherwise.
-    :rtype: :class:`bool`
+    :rtype: :obj:`bool`
 
     """
     return inbox == expected_inbox and interfaces.IShutdown(message, False)
@@ -203,7 +200,7 @@ def is_shutdown(inbox, message, expected_inbox='control'):
 def _strip_first_parameter(function_maker):
     """Strip the first parameter from a function signature.
 
-    This function ajusts a :class:`decorator.FunctionMaker` instance, removing
+    This function ajusts a :class:`!decorator.FunctionMaker` instance, removing
     the first parameter, along with it's default value if it has one.  It
     does not remove any :samp:`*{args}` or :samp:`**{kwargs}` parameters,
     however, even if they are the first parameter.  If there are no positional
@@ -212,9 +209,9 @@ def _strip_first_parameter(function_maker):
     This function is meant to make constructing certain signature-altering
     decorators easier to build.
 
-    :parameter function_maker: The :class:`~decorator.FunctionMaker` instance
+    :parameter function_maker: The :class:`!decorator.FunctionMaker` instance
       to alter.
-    :type function_maker: :class:`decorator.FunctionMaker`
+    :type function_maker: :class:`!decorator.FunctionMaker`
 
     """
     if not function_maker.args and not function_maker.varargs:
@@ -277,26 +274,23 @@ def _function_wrapper_from_template(function, template,
     will become global variables in the wrapper's namespace.  This is useful
     for passing in additional dependencies to the wrapper function.
 
-    :parameter function: The function to wrap and on which to base the
-      wrapper's signature, name and docstring.
-    :type function: :obj:`~types.FunctionType`
-    :parameter template: The template for the wrapper function.
-    :type template: :obj:`str` or :obj:`unicode`
-    :parameter strip_first_parameter: If :obj:`True`, the first parameter of
-      the given function's signature will be stripped off of the
+    :parameter types.FunctionType function: The function to wrap and on which
+      to base the wrapper's signature, name and docstring.
+    :parameter basestring template: The template for the wrapper function.
+    :parameter bool strip_first_parameter: If :obj:`True`, the first parameter
+      of the given function's signature will be stripped off of the
       ``%(signature)s`` variable used in the template.  Default is
       :obj:`False`.
-    :type strip_first_parameter: :obj:`bool`
 
     :returns: A wrapper function created from the given template.
-    :rtype: :obj:`~types.FunctionType`
+    :rtype: :data:`types.FunctionType`
 
-    :raises TypeError: If the first argument is not a function.
-    :raises ValueError: If *strip_first_parameter* is :obj:`True` and the given
-      function does not accept at least one parameter.
+    :raises exceptions.TypeError: If the first argument is not a function.
+    :raises exceptions.ValueError: If *strip_first_parameter* is :obj:`True`
+      and the given function does not accept at least one parameter.
     :raises SyntaxError: If the template is not valid.
 
-    :see also: :class:`decorator.FunctionMaker` for additional details on
+    :see also: :class:`!decorator.FunctionMaker` for additional details on
       templates and available variables.
 
     """
@@ -334,11 +328,13 @@ class _ObjectStandIn(object):
 
     This class is used by the :class:`_ObjectStandInRegistry`. Stand-ins can be
     used, for example, to hold attributes when for other objects that cannot
-    (i.e. :class:`~types.GeneratorType`) or in any other situation where using
+    (i.e. :data:`types.GeneratorType`) or in any other situation where using
     the original object is not suitable.
 
-    .. seealso:: :class:`_ObjectStandInRegistry` for details on how to work
-        with stand-ins.
+    .. seealso::
+
+      :class:`_ObjectStandInRegistry` for details on how to work with
+      stand-ins.
 
     """
 
@@ -393,7 +389,6 @@ class _ObjectStandInRegistry(object):
         same object again will return the same stand-in.
 
         :param object_: The object to register.
-        :type object_: *any*
 
         :returns: A stand-in object.
         :rtype: :class:`_ObjectStandIn`
@@ -405,11 +400,10 @@ class _ObjectStandInRegistry(object):
         """Return :obj:`True` if the object is registered in the registry.
 
         :param object_: The object to check.
-        :type object_: *any*
 
         :returns: :obj:`True` if the object is registered, :obj:`False`
           otherwise.
-        :rtype: :class:`bool`
+        :rtype: :obj:`bool`
 
         """
         return object_ in self._stand_ins
@@ -431,7 +425,6 @@ class _ObjectStandInRegistry(object):
         an object  that is already not registered will do nothing.
 
         :param object_: The registered object to remove.
-        :type object_: *any*
 
         """
         del self[object_]
@@ -440,12 +433,11 @@ class _ObjectStandInRegistry(object):
         """Teturn the stand-in for the given object.
 
         :param object_: The registered object to get.
-        :type object_: *any*
 
         :returns: The object's stand-in.
         :rtype: :class:`_ObjectStandIn`
 
-        :raises ValueError: If the object is not registered.
+        :raises exceptions.ValueError: If the object is not registered.
 
         """
         try:
