@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -32,13 +32,13 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
-## pylint: disable=E0611
+## pylint: disable=F0401
 from zope import interface
-## pylint: enable=E0611
+## pylint: enable=F0401
 
 #---  Project imports
 from m4us.core import api as core
@@ -75,10 +75,10 @@ class IThreadedCoroutine(core.ICoroutine):
     """
 
     ## pylint: disable=E0211
-    def start():
+    def start():  # pragma: no branch
         """Start the `coroutine` thread.
 
-        :raises RuntimeError: If the thread is already running.
+        :raises exceptions.RuntimeError: If the thread is already running.
 
         """
     ## pylint: enable=E0211
@@ -93,13 +93,13 @@ class IBackplaneFactory(core.ICoroutineFactory):
     ## pylint: disable=R0903
 
     ## pylint: disable=E0211
-    def __call__(*args, **kwargs):
+    def __call__(*args, **kwargs):  # pragma: no branch
         """Return the desired `backplane`.
 
-        :param args: Any arguments to pass to the `factory` `callable`.
-        :type args: :class:`tuple`
-        :param kwargs: Keywords arguments to pass to the `factory` `callable`.
-        :type kwargs: :class:`dict`
+        :param collections.Sequence args: Any arguments to pass to the
+          `factory` `callable`.
+        :param collections.Mapping kwargs: Keywords arguments to pass to the
+          `factory` `callable`.
 
         :returns: The desired `backplane` `coroutine`
         :rtype: :class:`IBackplane`
@@ -159,21 +159,17 @@ class IRegisterPublisher(core.IMessage):
 
     :param publisher: `Messages` providing this `interface` should require a
       publishing object, specified as a keyword argument.
-    :type publisher: :class:`object`
 
-    .. seealso:: The :class:`IBackplane` `interface` for details about
-        `messages` that use this `interface`.
+    .. seealso::
+
+      The :class:`IBackplane` `interface` for details about `messages` that use
+      this `interface`.
 
     """
 
     ## pylint: disable=R0903
 
-    publisher = interface.Attribute(
-        """The `publisher` object to register.
-
-        :type: :class:`object`
-
-        """)
+    publisher = interface.Attribute("""The `publisher` object to register.""")
 
 
 class IUnregisterPublisher(core.IMessage):
@@ -182,21 +178,19 @@ class IUnregisterPublisher(core.IMessage):
 
     :param publisher: `Messages` providing this `interface` should require a
       publishing object, specified as a keyword argument.
-    :type publisher: :class:`object`
 
-    .. seealso:: The :class:`IBackplane` `interface` for details about
-        `messages` that use this `interface`.
+    .. seealso::
+
+      The :class:`IBackplane` `interface` for details about `messages` that use
+      this `interface`.
 
     """
 
     ## pylint: disable=R0903
 
     publisher = interface.Attribute(
-        """The `publisher` object to un-register.
-
-        :type: :class:`object`
-
-        """)
+      """The `publisher` object to un-register."""
+    )
 
 
 #---Module initialization------------------------------------------------------
