@@ -3,7 +3,7 @@
 #---Header---------------------------------------------------------------------
 
 # This file is part of Message For You Sir (m4us).
-# Copyright © 2010 Krys Lawrence
+# Copyright © 2009-2012 Krys Lawrence
 #
 # Message For You Sir is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -30,7 +30,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 ## pylint: disable=W0622, W0611
-from future_builtins import ascii, filter, hex, map, oct, zip
+from future_builtins import ascii, filter, hex, map, oct, zip  ## NOQA
 ## pylint: enable=W0622, W0611
 
 #---  Third-party imports
@@ -75,7 +75,7 @@ class TestAPIModuleShouldIncludeAllCorePublicObjects(
         excludes = \
           support.APIModuleShouldIncludeAllPublicObjects._get_object_excludes(
           self)
-        return excludes + ('classProvides',)
+        return excludes + ('provider',)
 
 
 #---Module initialization------------------------------------------------------
